# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_TFCE_METADATA = Metadata(
    id="00af94a3601fb72ac5202dedc89a1c5c427cb460.boutiques",
    name="volume-tfce",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeTfcePresmoothParameters = typing.TypedDict('VolumeTfcePresmoothParameters', {
    "@type": typing.NotRequired[typing.Literal["presmooth"]],
    "kernel": float,
    "opt_fwhm": bool,
})
VolumeTfcePresmoothParametersTagged = typing.TypedDict('VolumeTfcePresmoothParametersTagged', {
    "@type": typing.Literal["presmooth"],
    "kernel": float,
    "opt_fwhm": bool,
})


VolumeTfceParametersParameters = typing.TypedDict('VolumeTfceParametersParameters', {
    "@type": typing.NotRequired[typing.Literal["parameters"]],
    "e": float,
    "h": float,
})
VolumeTfceParametersParametersTagged = typing.TypedDict('VolumeTfceParametersParametersTagged', {
    "@type": typing.Literal["parameters"],
    "e": float,
    "h": float,
})


VolumeTfceParameters = typing.TypedDict('VolumeTfceParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-tfce"]],
    "volume_in": InputPathType,
    "volume_out": str,
    "presmooth": typing.NotRequired[VolumeTfcePresmoothParameters | None],
    "opt_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "parameters": typing.NotRequired[VolumeTfceParametersParameters | None],
    "opt_subvolume_subvolume": typing.NotRequired[str | None],
})
VolumeTfceParametersTagged = typing.TypedDict('VolumeTfceParametersTagged', {
    "@type": typing.Literal["workbench/volume-tfce"],
    "volume_in": InputPathType,
    "volume_out": str,
    "presmooth": typing.NotRequired[VolumeTfcePresmoothParameters | None],
    "opt_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "parameters": typing.NotRequired[VolumeTfceParametersParameters | None],
    "opt_subvolume_subvolume": typing.NotRequired[str | None],
})


def volume_tfce_presmooth_params(
    kernel: float,
    opt_fwhm: bool = False,
) -> VolumeTfcePresmoothParametersTagged:
    """
    Build parameters.
    
    Args:
        kernel: the size of the gaussian smoothing kernel in mm, as sigma by\
            default.
        opt_fwhm: smoothing kernel size is FWHM, not sigma.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "presmooth",
        "kernel": kernel,
        "opt_fwhm": opt_fwhm,
    }
    return params


def volume_tfce_presmooth_cargs(
    params: VolumeTfcePresmoothParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-presmooth")
    cargs.append(str(params.get("kernel", None)))
    if params.get("opt_fwhm", False):
        cargs.append("-fwhm")
    return cargs


def volume_tfce_parameters_params(
    e: float,
    h: float,
) -> VolumeTfceParametersParametersTagged:
    """
    Build parameters.
    
    Args:
        e: exponent for cluster volume (default 0.5).
        h: exponent for threshold value (default 2.0).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "parameters",
        "e": e,
        "h": h,
    }
    return params


def volume_tfce_parameters_cargs(
    params: VolumeTfceParametersParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-parameters")
    cargs.append(str(params.get("e", None)))
    cargs.append(str(params.get("h", None)))
    return cargs


class VolumeTfceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeTfceParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_tfce_params(
    volume_in: InputPathType,
    volume_out: str,
    presmooth: VolumeTfcePresmoothParameters | None = None,
    opt_roi_roi_volume: InputPathType | None = None,
    parameters: VolumeTfceParametersParameters | None = None,
    opt_subvolume_subvolume: str | None = None,
) -> VolumeTfceParametersTagged:
    """
    Build parameters.
    
    Args:
        volume_in: the volume to run TFCE on.
        volume_out: the output volume.
        presmooth: smooth the volume before running TFCE.
        opt_roi_roi_volume: select a region of interest to run TFCE on: the\
            area to run TFCE on, as a volume.
        parameters: set parameters for TFCE integral.
        opt_subvolume_subvolume: select a single subvolume: the subvolume\
            number or name.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-tfce",
        "volume_in": volume_in,
        "volume_out": volume_out,
    }
    if presmooth is not None:
        params["presmooth"] = presmooth
    if opt_roi_roi_volume is not None:
        params["opt_roi_roi_volume"] = opt_roi_roi_volume
    if parameters is not None:
        params["parameters"] = parameters
    if opt_subvolume_subvolume is not None:
        params["opt_subvolume_subvolume"] = opt_subvolume_subvolume
    return params


def volume_tfce_cargs(
    params: VolumeTfceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-tfce")
    cargs.append(execution.input_file(params.get("volume_in", None)))
    cargs.append(params.get("volume_out", None))
    if params.get("presmooth", None) is not None:
        cargs.extend(volume_tfce_presmooth_cargs(params.get("presmooth", None), execution))
    if params.get("opt_roi_roi_volume", None) is not None:
        cargs.extend([
            "-roi",
            execution.input_file(params.get("opt_roi_roi_volume", None))
        ])
    if params.get("parameters", None) is not None:
        cargs.extend(volume_tfce_parameters_cargs(params.get("parameters", None), execution))
    if params.get("opt_subvolume_subvolume", None) is not None:
        cargs.extend([
            "-subvolume",
            params.get("opt_subvolume_subvolume", None)
        ])
    return cargs


def volume_tfce_outputs(
    params: VolumeTfceParameters,
    execution: Execution,
) -> VolumeTfceOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeTfceOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_tfce_execute(
    params: VolumeTfceParameters,
    runner: Runner | None = None,
) -> VolumeTfceOutputs:
    """
    volume-tfce
    
    Do tfce on a volume file.
    
    This command does not do any statistical analysis. Please use something like
    PALM if you are just trying to do statistics on your data.
    
    Threshold-free cluster enhancement is a method to increase the relative
    value of regions that would form clusters in a standard thresholding test.
    This is accomplished by evaluating the integral of:
    
    e(h, p)^E * h^H * dh
    
    at each voxel p, where h ranges from 0 to the maximum value in the data, and
    e(h, p) is the extent of the cluster containing voxel p at threshold h.
    Negative values are similarly enhanced by negating the data, running the
    same process, and negating the result.
    
    This method is explained in: Smith SM, Nichols TE., "Threshold-free cluster
    enhancement: addressing problems of smoothing, threshold dependence and
    localisation in cluster inference." Neuroimage. 2009 Jan 1;44(1):83-98.
    PMID: 18501637.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeTfceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_TFCE_METADATA)
    params = execution.params(params)
    cargs = volume_tfce_cargs(params, execution)
    ret = volume_tfce_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_tfce(
    volume_in: InputPathType,
    volume_out: str,
    presmooth: VolumeTfcePresmoothParameters | None = None,
    opt_roi_roi_volume: InputPathType | None = None,
    parameters: VolumeTfceParametersParameters | None = None,
    opt_subvolume_subvolume: str | None = None,
    runner: Runner | None = None,
) -> VolumeTfceOutputs:
    """
    volume-tfce
    
    Do tfce on a volume file.
    
    This command does not do any statistical analysis. Please use something like
    PALM if you are just trying to do statistics on your data.
    
    Threshold-free cluster enhancement is a method to increase the relative
    value of regions that would form clusters in a standard thresholding test.
    This is accomplished by evaluating the integral of:
    
    e(h, p)^E * h^H * dh
    
    at each voxel p, where h ranges from 0 to the maximum value in the data, and
    e(h, p) is the extent of the cluster containing voxel p at threshold h.
    Negative values are similarly enhanced by negating the data, running the
    same process, and negating the result.
    
    This method is explained in: Smith SM, Nichols TE., "Threshold-free cluster
    enhancement: addressing problems of smoothing, threshold dependence and
    localisation in cluster inference." Neuroimage. 2009 Jan 1;44(1):83-98.
    PMID: 18501637.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: the volume to run TFCE on.
        volume_out: the output volume.
        presmooth: smooth the volume before running TFCE.
        opt_roi_roi_volume: select a region of interest to run TFCE on: the\
            area to run TFCE on, as a volume.
        parameters: set parameters for TFCE integral.
        opt_subvolume_subvolume: select a single subvolume: the subvolume\
            number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeTfceOutputs`).
    """
    params = volume_tfce_params(
        volume_in=volume_in,
        volume_out=volume_out,
        presmooth=presmooth,
        opt_roi_roi_volume=opt_roi_roi_volume,
        parameters=parameters,
        opt_subvolume_subvolume=opt_subvolume_subvolume,
    )
    return volume_tfce_execute(params, runner)


__all__ = [
    "VOLUME_TFCE_METADATA",
    "VolumeTfceOutputs",
    "volume_tfce",
    "volume_tfce_execute",
    "volume_tfce_parameters_params",
    "volume_tfce_params",
    "volume_tfce_presmooth_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ESTIMATE_FIBER_BINGHAMS_METADATA = Metadata(
    id="2c33f5d971543b2fe7a2401a0a23b45df09ab673.boutiques",
    name="estimate-fiber-binghams",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


EstimateFiberBinghamsParameters = typing.TypedDict('EstimateFiberBinghamsParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/estimate-fiber-binghams"]],
    "merged_f1samples": InputPathType,
    "merged_th1samples": InputPathType,
    "merged_ph1samples": InputPathType,
    "merged_f2samples": InputPathType,
    "merged_th2samples": InputPathType,
    "merged_ph2samples": InputPathType,
    "merged_f3samples": InputPathType,
    "merged_th3samples": InputPathType,
    "merged_ph3samples": InputPathType,
    "label_volume": InputPathType,
    "cifti_out": str,
})
EstimateFiberBinghamsParametersTagged = typing.TypedDict('EstimateFiberBinghamsParametersTagged', {
    "@type": typing.Literal["workbench/estimate-fiber-binghams"],
    "merged_f1samples": InputPathType,
    "merged_th1samples": InputPathType,
    "merged_ph1samples": InputPathType,
    "merged_f2samples": InputPathType,
    "merged_th2samples": InputPathType,
    "merged_ph2samples": InputPathType,
    "merged_f3samples": InputPathType,
    "merged_th3samples": InputPathType,
    "merged_ph3samples": InputPathType,
    "label_volume": InputPathType,
    "cifti_out": str,
})


class EstimateFiberBinghamsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `EstimateFiberBinghamsParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """output cifti fiber distributons file"""


def estimate_fiber_binghams_params(
    merged_f1samples: InputPathType,
    merged_th1samples: InputPathType,
    merged_ph1samples: InputPathType,
    merged_f2samples: InputPathType,
    merged_th2samples: InputPathType,
    merged_ph2samples: InputPathType,
    merged_f3samples: InputPathType,
    merged_th3samples: InputPathType,
    merged_ph3samples: InputPathType,
    label_volume: InputPathType,
    cifti_out: str,
) -> EstimateFiberBinghamsParametersTagged:
    """
    Build parameters.
    
    Args:
        merged_f1samples: fiber 1 strength samples.
        merged_th1samples: fiber 1 theta samples.
        merged_ph1samples: fiber 1 phi samples.
        merged_f2samples: fiber 2 strength samples.
        merged_th2samples: fiber 2 theta samples.
        merged_ph2samples: fiber 2 phi samples.
        merged_f3samples: fiber 3 strength samples.
        merged_th3samples: fiber 3 theta samples.
        merged_ph3samples: fiber 3 phi samples.
        label_volume: volume of cifti structure labels.
        cifti_out: output cifti fiber distributons file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/estimate-fiber-binghams",
        "merged_f1samples": merged_f1samples,
        "merged_th1samples": merged_th1samples,
        "merged_ph1samples": merged_ph1samples,
        "merged_f2samples": merged_f2samples,
        "merged_th2samples": merged_th2samples,
        "merged_ph2samples": merged_ph2samples,
        "merged_f3samples": merged_f3samples,
        "merged_th3samples": merged_th3samples,
        "merged_ph3samples": merged_ph3samples,
        "label_volume": label_volume,
        "cifti_out": cifti_out,
    }
    return params


def estimate_fiber_binghams_cargs(
    params: EstimateFiberBinghamsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-estimate-fiber-binghams")
    cargs.append(execution.input_file(params.get("merged_f1samples", None)))
    cargs.append(execution.input_file(params.get("merged_th1samples", None)))
    cargs.append(execution.input_file(params.get("merged_ph1samples", None)))
    cargs.append(execution.input_file(params.get("merged_f2samples", None)))
    cargs.append(execution.input_file(params.get("merged_th2samples", None)))
    cargs.append(execution.input_file(params.get("merged_ph2samples", None)))
    cargs.append(execution.input_file(params.get("merged_f3samples", None)))
    cargs.append(execution.input_file(params.get("merged_th3samples", None)))
    cargs.append(execution.input_file(params.get("merged_ph3samples", None)))
    cargs.append(execution.input_file(params.get("label_volume", None)))
    cargs.append(params.get("cifti_out", None))
    return cargs


def estimate_fiber_binghams_outputs(
    params: EstimateFiberBinghamsParameters,
    execution: Execution,
) -> EstimateFiberBinghamsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = EstimateFiberBinghamsOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def estimate_fiber_binghams_execute(
    params: EstimateFiberBinghamsParameters,
    runner: Runner | None = None,
) -> EstimateFiberBinghamsOutputs:
    """
    estimate-fiber-binghams
    
    Estimate fiber orientation distributions from bedpostx samples.
    
    This command does an estimation of a bingham distribution for each fiber
    orientation in each voxel which is labeled a structure identifier. These
    labelings come from the <label-volume> argument, which must have labels that
    match the following strings:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EstimateFiberBinghamsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ESTIMATE_FIBER_BINGHAMS_METADATA)
    params = execution.params(params)
    cargs = estimate_fiber_binghams_cargs(params, execution)
    ret = estimate_fiber_binghams_outputs(params, execution)
    execution.run(cargs)
    return ret


def estimate_fiber_binghams(
    merged_f1samples: InputPathType,
    merged_th1samples: InputPathType,
    merged_ph1samples: InputPathType,
    merged_f2samples: InputPathType,
    merged_th2samples: InputPathType,
    merged_ph2samples: InputPathType,
    merged_f3samples: InputPathType,
    merged_th3samples: InputPathType,
    merged_ph3samples: InputPathType,
    label_volume: InputPathType,
    cifti_out: str,
    runner: Runner | None = None,
) -> EstimateFiberBinghamsOutputs:
    """
    estimate-fiber-binghams
    
    Estimate fiber orientation distributions from bedpostx samples.
    
    This command does an estimation of a bingham distribution for each fiber
    orientation in each voxel which is labeled a structure identifier. These
    labelings come from the <label-volume> argument, which must have labels that
    match the following strings:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        merged_f1samples: fiber 1 strength samples.
        merged_th1samples: fiber 1 theta samples.
        merged_ph1samples: fiber 1 phi samples.
        merged_f2samples: fiber 2 strength samples.
        merged_th2samples: fiber 2 theta samples.
        merged_ph2samples: fiber 2 phi samples.
        merged_f3samples: fiber 3 strength samples.
        merged_th3samples: fiber 3 theta samples.
        merged_ph3samples: fiber 3 phi samples.
        label_volume: volume of cifti structure labels.
        cifti_out: output cifti fiber distributons file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EstimateFiberBinghamsOutputs`).
    """
    params = estimate_fiber_binghams_params(
        merged_f1samples=merged_f1samples,
        merged_th1samples=merged_th1samples,
        merged_ph1samples=merged_ph1samples,
        merged_f2samples=merged_f2samples,
        merged_th2samples=merged_th2samples,
        merged_ph2samples=merged_ph2samples,
        merged_f3samples=merged_f3samples,
        merged_th3samples=merged_th3samples,
        merged_ph3samples=merged_ph3samples,
        label_volume=label_volume,
        cifti_out=cifti_out,
    )
    return estimate_fiber_binghams_execute(params, runner)


__all__ = [
    "ESTIMATE_FIBER_BINGHAMS_METADATA",
    "EstimateFiberBinghamsOutputs",
    "estimate_fiber_binghams",
    "estimate_fiber_binghams_execute",
    "estimate_fiber_binghams_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_STATS_METADATA = Metadata(
    id="aee8e35b38c06ea18eeb42aa6c5076216e3ebc0c.boutiques",
    name="volume-stats",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeStatsRoiParameters = typing.TypedDict('VolumeStatsRoiParameters', {
    "@type": typing.NotRequired[typing.Literal["roi"]],
    "roi_volume": InputPathType,
    "opt_match_maps": bool,
})
VolumeStatsRoiParametersTagged = typing.TypedDict('VolumeStatsRoiParametersTagged', {
    "@type": typing.Literal["roi"],
    "roi_volume": InputPathType,
    "opt_match_maps": bool,
})


VolumeStatsParameters = typing.TypedDict('VolumeStatsParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-stats"]],
    "volume_in": InputPathType,
    "opt_reduce_operation": typing.NotRequired[str | None],
    "opt_percentile_percent": typing.NotRequired[float | None],
    "opt_subvolume_subvolume": typing.NotRequired[str | None],
    "roi": typing.NotRequired[VolumeStatsRoiParameters | None],
    "opt_show_map_name": bool,
})
VolumeStatsParametersTagged = typing.TypedDict('VolumeStatsParametersTagged', {
    "@type": typing.Literal["workbench/volume-stats"],
    "volume_in": InputPathType,
    "opt_reduce_operation": typing.NotRequired[str | None],
    "opt_percentile_percent": typing.NotRequired[float | None],
    "opt_subvolume_subvolume": typing.NotRequired[str | None],
    "roi": typing.NotRequired[VolumeStatsRoiParameters | None],
    "opt_show_map_name": bool,
})


def volume_stats_roi_params(
    roi_volume: InputPathType,
    opt_match_maps: bool = False,
) -> VolumeStatsRoiParametersTagged:
    """
    Build parameters.
    
    Args:
        roi_volume: the roi, as a volume file.
        opt_match_maps: each subvolume of input uses the corresponding\
            subvolume from the roi file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "roi",
        "roi_volume": roi_volume,
        "opt_match_maps": opt_match_maps,
    }
    return params


def volume_stats_roi_cargs(
    params: VolumeStatsRoiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-roi")
    cargs.append(execution.input_file(params.get("roi_volume", None)))
    if params.get("opt_match_maps", False):
        cargs.append("-match-maps")
    return cargs


class VolumeStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeStatsParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def volume_stats_params(
    volume_in: InputPathType,
    opt_reduce_operation: str | None = None,
    opt_percentile_percent: float | None = None,
    opt_subvolume_subvolume: str | None = None,
    roi: VolumeStatsRoiParameters | None = None,
    opt_show_map_name: bool = False,
) -> VolumeStatsParametersTagged:
    """
    Build parameters.
    
    Args:
        volume_in: the input volume.
        opt_reduce_operation: use a reduction operation: the reduction\
            operation.
        opt_percentile_percent: give the value at a percentile: the percentile\
            to find, must be between 0 and 100.
        opt_subvolume_subvolume: only display output for one subvolume: the\
            subvolume number or name.
        roi: only consider data inside an roi.
        opt_show_map_name: print map index and name before each output.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-stats",
        "volume_in": volume_in,
        "opt_show_map_name": opt_show_map_name,
    }
    if opt_reduce_operation is not None:
        params["opt_reduce_operation"] = opt_reduce_operation
    if opt_percentile_percent is not None:
        params["opt_percentile_percent"] = opt_percentile_percent
    if opt_subvolume_subvolume is not None:
        params["opt_subvolume_subvolume"] = opt_subvolume_subvolume
    if roi is not None:
        params["roi"] = roi
    return params


def volume_stats_cargs(
    params: VolumeStatsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-stats")
    cargs.append(execution.input_file(params.get("volume_in", None)))
    if params.get("opt_reduce_operation", None) is not None:
        cargs.extend([
            "-reduce",
            params.get("opt_reduce_operation", None)
        ])
    if params.get("opt_percentile_percent", None) is not None:
        cargs.extend([
            "-percentile",
            str(params.get("opt_percentile_percent", None))
        ])
    if params.get("opt_subvolume_subvolume", None) is not None:
        cargs.extend([
            "-subvolume",
            params.get("opt_subvolume_subvolume", None)
        ])
    if params.get("roi", None) is not None:
        cargs.extend(volume_stats_roi_cargs(params.get("roi", None), execution))
    if params.get("opt_show_map_name", False):
        cargs.append("-show-map-name")
    return cargs


def volume_stats_outputs(
    params: VolumeStatsParameters,
    execution: Execution,
) -> VolumeStatsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeStatsOutputs(
        root=execution.output_file("."),
    )
    return ret


def volume_stats_execute(
    params: VolumeStatsParameters,
    runner: Runner | None = None,
) -> VolumeStatsOutputs:
    """
    volume-stats
    
    Spatial statistics on a volume file.
    
    For each subvolume of the input, a line of text is printed, resulting from
    the specified reduction or percentile operation. Use -subvolume to only give
    output for a single subvolume. If the -roi option is used without
    -match-maps, then each line will contain as many numbers as there are maps
    in the ROI file, separated by tab characters. Exactly one of -reduce or
    -percentile must be specified.
    
    The argument to the -reduce option must be one of the following:
    
    MAX: the maximum value
    MIN: the minimum value
    INDEXMAX: the 1-based index of the maximum value
    INDEXMIN: the 1-based index of the minimum value
    SUM: add all values
    PRODUCT: multiply all values
    MEAN: the mean of the data
    STDEV: the standard deviation (N denominator)
    SAMPSTDEV: the sample standard deviation (N-1 denominator)
    VARIANCE: the variance of the data
    TSNR: mean divided by sample standard deviation (N-1 denominator)
    COV: sample standard deviation (N-1 denominator) divided by mean
    L2NORM: square root of sum of squares
    MEDIAN: the median of the data
    MODE: the mode of the data
    COUNT_NONZERO: the number of nonzero elements in the data
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_STATS_METADATA)
    params = execution.params(params)
    cargs = volume_stats_cargs(params, execution)
    ret = volume_stats_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_stats(
    volume_in: InputPathType,
    opt_reduce_operation: str | None = None,
    opt_percentile_percent: float | None = None,
    opt_subvolume_subvolume: str | None = None,
    roi: VolumeStatsRoiParameters | None = None,
    opt_show_map_name: bool = False,
    runner: Runner | None = None,
) -> VolumeStatsOutputs:
    """
    volume-stats
    
    Spatial statistics on a volume file.
    
    For each subvolume of the input, a line of text is printed, resulting from
    the specified reduction or percentile operation. Use -subvolume to only give
    output for a single subvolume. If the -roi option is used without
    -match-maps, then each line will contain as many numbers as there are maps
    in the ROI file, separated by tab characters. Exactly one of -reduce or
    -percentile must be specified.
    
    The argument to the -reduce option must be one of the following:
    
    MAX: the maximum value
    MIN: the minimum value
    INDEXMAX: the 1-based index of the maximum value
    INDEXMIN: the 1-based index of the minimum value
    SUM: add all values
    PRODUCT: multiply all values
    MEAN: the mean of the data
    STDEV: the standard deviation (N denominator)
    SAMPSTDEV: the sample standard deviation (N-1 denominator)
    VARIANCE: the variance of the data
    TSNR: mean divided by sample standard deviation (N-1 denominator)
    COV: sample standard deviation (N-1 denominator) divided by mean
    L2NORM: square root of sum of squares
    MEDIAN: the median of the data
    MODE: the mode of the data
    COUNT_NONZERO: the number of nonzero elements in the data
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: the input volume.
        opt_reduce_operation: use a reduction operation: the reduction\
            operation.
        opt_percentile_percent: give the value at a percentile: the percentile\
            to find, must be between 0 and 100.
        opt_subvolume_subvolume: only display output for one subvolume: the\
            subvolume number or name.
        roi: only consider data inside an roi.
        opt_show_map_name: print map index and name before each output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeStatsOutputs`).
    """
    params = volume_stats_params(
        volume_in=volume_in,
        opt_reduce_operation=opt_reduce_operation,
        opt_percentile_percent=opt_percentile_percent,
        opt_subvolume_subvolume=opt_subvolume_subvolume,
        roi=roi,
        opt_show_map_name=opt_show_map_name,
    )
    return volume_stats_execute(params, runner)


__all__ = [
    "VOLUME_STATS_METADATA",
    "VolumeStatsOutputs",
    "volume_stats",
    "volume_stats_execute",
    "volume_stats_params",
    "volume_stats_roi_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_TO_SURFACE_3D_DISTANCE_METADATA = Metadata(
    id="c626cddf06128e06492b24180056cbbcb098a4c4.boutiques",
    name="surface-to-surface-3d-distance",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceToSurface3dDistanceParameters = typing.TypedDict('SurfaceToSurface3dDistanceParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-to-surface-3d-distance"]],
    "surface_comp": InputPathType,
    "surface_ref": InputPathType,
    "dists_out": str,
    "opt_vectors_vectors_out": typing.NotRequired[str | None],
})
SurfaceToSurface3dDistanceParametersTagged = typing.TypedDict('SurfaceToSurface3dDistanceParametersTagged', {
    "@type": typing.Literal["workbench/surface-to-surface-3d-distance"],
    "surface_comp": InputPathType,
    "surface_ref": InputPathType,
    "dists_out": str,
    "opt_vectors_vectors_out": typing.NotRequired[str | None],
})


class SurfaceToSurface3dDistanceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceToSurface3dDistanceParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    dists_out: OutputPathType
    """the output distances"""
    opt_vectors_vectors_out: OutputPathType | None
    """output the displacement vectors: the output vectors"""


def surface_to_surface_3d_distance_params(
    surface_comp: InputPathType,
    surface_ref: InputPathType,
    dists_out: str,
    opt_vectors_vectors_out: str | None = None,
) -> SurfaceToSurface3dDistanceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface_comp: the surface to compare to the reference.
        surface_ref: the surface to use as the reference.
        dists_out: the output distances.
        opt_vectors_vectors_out: output the displacement vectors: the output\
            vectors.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-to-surface-3d-distance",
        "surface_comp": surface_comp,
        "surface_ref": surface_ref,
        "dists_out": dists_out,
    }
    if opt_vectors_vectors_out is not None:
        params["opt_vectors_vectors_out"] = opt_vectors_vectors_out
    return params


def surface_to_surface_3d_distance_cargs(
    params: SurfaceToSurface3dDistanceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-to-surface-3d-distance")
    cargs.append(execution.input_file(params.get("surface_comp", None)))
    cargs.append(execution.input_file(params.get("surface_ref", None)))
    cargs.append(params.get("dists_out", None))
    if params.get("opt_vectors_vectors_out", None) is not None:
        cargs.extend([
            "-vectors",
            params.get("opt_vectors_vectors_out", None)
        ])
    return cargs


def surface_to_surface_3d_distance_outputs(
    params: SurfaceToSurface3dDistanceParameters,
    execution: Execution,
) -> SurfaceToSurface3dDistanceOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceToSurface3dDistanceOutputs(
        root=execution.output_file("."),
        dists_out=execution.output_file(params.get("dists_out", None)),
        opt_vectors_vectors_out=execution.output_file(params.get("opt_vectors_vectors_out", None)) if (params.get("opt_vectors_vectors_out") is not None) else None,
    )
    return ret


def surface_to_surface_3d_distance_execute(
    params: SurfaceToSurface3dDistanceParameters,
    runner: Runner | None = None,
) -> SurfaceToSurface3dDistanceOutputs:
    """
    surface-to-surface-3d-distance
    
    Compute distance between corresponding vertices.
    
    Computes the vector difference between the vertices of each surface with the
    same index, as (comp - ref), and output the magnitudes, and optionally the
    displacement vectors.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceToSurface3dDistanceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_TO_SURFACE_3D_DISTANCE_METADATA)
    params = execution.params(params)
    cargs = surface_to_surface_3d_distance_cargs(params, execution)
    ret = surface_to_surface_3d_distance_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_to_surface_3d_distance(
    surface_comp: InputPathType,
    surface_ref: InputPathType,
    dists_out: str,
    opt_vectors_vectors_out: str | None = None,
    runner: Runner | None = None,
) -> SurfaceToSurface3dDistanceOutputs:
    """
    surface-to-surface-3d-distance
    
    Compute distance between corresponding vertices.
    
    Computes the vector difference between the vertices of each surface with the
    same index, as (comp - ref), and output the magnitudes, and optionally the
    displacement vectors.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface_comp: the surface to compare to the reference.
        surface_ref: the surface to use as the reference.
        dists_out: the output distances.
        opt_vectors_vectors_out: output the displacement vectors: the output\
            vectors.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceToSurface3dDistanceOutputs`).
    """
    params = surface_to_surface_3d_distance_params(
        surface_comp=surface_comp,
        surface_ref=surface_ref,
        dists_out=dists_out,
        opt_vectors_vectors_out=opt_vectors_vectors_out,
    )
    return surface_to_surface_3d_distance_execute(params, runner)


__all__ = [
    "SURFACE_TO_SURFACE_3D_DISTANCE_METADATA",
    "SurfaceToSurface3dDistanceOutputs",
    "surface_to_surface_3d_distance",
    "surface_to_surface_3d_distance_execute",
    "surface_to_surface_3d_distance_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SIGNED_DISTANCE_TO_SURFACE_METADATA = Metadata(
    id="8c819d933d40718709f36a80f07be61f04dd0058.boutiques",
    name="signed-distance-to-surface",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SignedDistanceToSurfaceParameters = typing.TypedDict('SignedDistanceToSurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/signed-distance-to-surface"]],
    "surface_comp": InputPathType,
    "surface_ref": InputPathType,
    "metric": str,
    "opt_winding_method": typing.NotRequired[str | None],
})
SignedDistanceToSurfaceParametersTagged = typing.TypedDict('SignedDistanceToSurfaceParametersTagged', {
    "@type": typing.Literal["workbench/signed-distance-to-surface"],
    "surface_comp": InputPathType,
    "surface_ref": InputPathType,
    "metric": str,
    "opt_winding_method": typing.NotRequired[str | None],
})


class SignedDistanceToSurfaceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SignedDistanceToSurfaceParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric: OutputPathType
    """the output metric"""


def signed_distance_to_surface_params(
    surface_comp: InputPathType,
    surface_ref: InputPathType,
    metric: str,
    opt_winding_method: str | None = None,
) -> SignedDistanceToSurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface_comp: the comparison surface to measure the signed distance on.
        surface_ref: the reference surface that defines the signed distance\
            function.
        metric: the output metric.
        opt_winding_method: winding method for point inside surface test: name\
            of the method (default EVEN_ODD).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/signed-distance-to-surface",
        "surface_comp": surface_comp,
        "surface_ref": surface_ref,
        "metric": metric,
    }
    if opt_winding_method is not None:
        params["opt_winding_method"] = opt_winding_method
    return params


def signed_distance_to_surface_cargs(
    params: SignedDistanceToSurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-signed-distance-to-surface")
    cargs.append(execution.input_file(params.get("surface_comp", None)))
    cargs.append(execution.input_file(params.get("surface_ref", None)))
    cargs.append(params.get("metric", None))
    if params.get("opt_winding_method", None) is not None:
        cargs.extend([
            "-winding",
            params.get("opt_winding_method", None)
        ])
    return cargs


def signed_distance_to_surface_outputs(
    params: SignedDistanceToSurfaceParameters,
    execution: Execution,
) -> SignedDistanceToSurfaceOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SignedDistanceToSurfaceOutputs(
        root=execution.output_file("."),
        metric=execution.output_file(params.get("metric", None)),
    )
    return ret


def signed_distance_to_surface_execute(
    params: SignedDistanceToSurfaceParameters,
    runner: Runner | None = None,
) -> SignedDistanceToSurfaceOutputs:
    """
    signed-distance-to-surface
    
    Compute signed distance from one surface to another.
    
    Compute the signed distance function of the reference surface at every
    vertex on the comparison surface. NOTE: this relation is NOT symmetric, the
    line from a vertex to the closest point on the 'ref' surface (the one that
    defines the signed distance function) will only align with the normal of the
    'ref' surface. Valid specifiers for winding methods are as follows:
    
    EVEN_ODD (default)
    NEGATIVE
    NONZERO
    NORMALS
    
    The NORMALS method uses the normals of triangles and edges, or the closest
    triangle hit by a ray from the point. This method may be slightly faster,
    but is only reliable for a closed surface that does not cross through
    itself. All other methods count entry (positive) and exit (negative)
    crossings of a vertical ray from the point, then counts as inside if the
    total is odd, negative, or nonzero, respectively.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SignedDistanceToSurfaceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SIGNED_DISTANCE_TO_SURFACE_METADATA)
    params = execution.params(params)
    cargs = signed_distance_to_surface_cargs(params, execution)
    ret = signed_distance_to_surface_outputs(params, execution)
    execution.run(cargs)
    return ret


def signed_distance_to_surface(
    surface_comp: InputPathType,
    surface_ref: InputPathType,
    metric: str,
    opt_winding_method: str | None = None,
    runner: Runner | None = None,
) -> SignedDistanceToSurfaceOutputs:
    """
    signed-distance-to-surface
    
    Compute signed distance from one surface to another.
    
    Compute the signed distance function of the reference surface at every
    vertex on the comparison surface. NOTE: this relation is NOT symmetric, the
    line from a vertex to the closest point on the 'ref' surface (the one that
    defines the signed distance function) will only align with the normal of the
    'ref' surface. Valid specifiers for winding methods are as follows:
    
    EVEN_ODD (default)
    NEGATIVE
    NONZERO
    NORMALS
    
    The NORMALS method uses the normals of triangles and edges, or the closest
    triangle hit by a ray from the point. This method may be slightly faster,
    but is only reliable for a closed surface that does not cross through
    itself. All other methods count entry (positive) and exit (negative)
    crossings of a vertical ray from the point, then counts as inside if the
    total is odd, negative, or nonzero, respectively.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface_comp: the comparison surface to measure the signed distance on.
        surface_ref: the reference surface that defines the signed distance\
            function.
        metric: the output metric.
        opt_winding_method: winding method for point inside surface test: name\
            of the method (default EVEN_ODD).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SignedDistanceToSurfaceOutputs`).
    """
    params = signed_distance_to_surface_params(
        surface_comp=surface_comp,
        surface_ref=surface_ref,
        metric=metric,
        opt_winding_method=opt_winding_method,
    )
    return signed_distance_to_surface_execute(params, runner)


__all__ = [
    "SIGNED_DISTANCE_TO_SURFACE_METADATA",
    "SignedDistanceToSurfaceOutputs",
    "signed_distance_to_surface",
    "signed_distance_to_surface_execute",
    "signed_distance_to_surface_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_LABEL_TO_BORDER_METADATA = Metadata(
    id="47da628bfbf4e955d157fbb860fd530ed67ce718.boutiques",
    name="cifti-label-to-border",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiLabelToBorderBorderParameters = typing.TypedDict('CiftiLabelToBorderBorderParameters', {
    "@type": typing.NotRequired[typing.Literal["border"]],
    "surface": InputPathType,
    "border_out": str,
})
CiftiLabelToBorderBorderParametersTagged = typing.TypedDict('CiftiLabelToBorderBorderParametersTagged', {
    "@type": typing.Literal["border"],
    "surface": InputPathType,
    "border_out": str,
})


CiftiLabelToBorderParameters = typing.TypedDict('CiftiLabelToBorderParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-label-to-border"]],
    "cifti_in": InputPathType,
    "opt_placement_fraction": typing.NotRequired[float | None],
    "opt_column_column": typing.NotRequired[str | None],
    "border": typing.NotRequired[list[CiftiLabelToBorderBorderParameters] | None],
})
CiftiLabelToBorderParametersTagged = typing.TypedDict('CiftiLabelToBorderParametersTagged', {
    "@type": typing.Literal["workbench/cifti-label-to-border"],
    "cifti_in": InputPathType,
    "opt_placement_fraction": typing.NotRequired[float | None],
    "opt_column_column": typing.NotRequired[str | None],
    "border": typing.NotRequired[list[CiftiLabelToBorderBorderParameters] | None],
})


class CiftiLabelToBorderBorderOutputs(typing.NamedTuple):
    """
    Output object returned when calling `list[CiftiLabelToBorderBorderParameters] | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    border_out: OutputPathType
    """the output border file"""


def cifti_label_to_border_border_params(
    surface: InputPathType,
    border_out: str,
) -> CiftiLabelToBorderBorderParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to use for neighbor and structure information.
        border_out: the output border file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "border",
        "surface": surface,
        "border_out": border_out,
    }
    return params


def cifti_label_to_border_border_cargs(
    params: CiftiLabelToBorderBorderParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-border")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(params.get("border_out", None))
    return cargs


def cifti_label_to_border_border_outputs(
    params: CiftiLabelToBorderBorderParameters,
    execution: Execution,
) -> CiftiLabelToBorderBorderOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiLabelToBorderBorderOutputs(
        root=execution.output_file("."),
        border_out=execution.output_file(params.get("border_out", None)),
    )
    return ret


class CiftiLabelToBorderOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiLabelToBorderParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    border: list[CiftiLabelToBorderBorderOutputs] | None
    """Outputs from `cifti_label_to_border_border_outputs`.This is a list of
    outputs with the same length and order as the inputs."""


def cifti_label_to_border_params(
    cifti_in: InputPathType,
    opt_placement_fraction: float | None = None,
    opt_column_column: str | None = None,
    border: list[CiftiLabelToBorderBorderParameters] | None = None,
) -> CiftiLabelToBorderParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the input cifti dlabel file.
        opt_placement_fraction: set how far along the edge border points are\
            drawn: fraction along edge from inside vertex (default 0.33).
        opt_column_column: select a single column: the column number or name.
        border: specify output file for a surface structure.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-label-to-border",
        "cifti_in": cifti_in,
    }
    if opt_placement_fraction is not None:
        params["opt_placement_fraction"] = opt_placement_fraction
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    if border is not None:
        params["border"] = border
    return params


def cifti_label_to_border_cargs(
    params: CiftiLabelToBorderParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-label-to-border")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    if params.get("opt_placement_fraction", None) is not None:
        cargs.extend([
            "-placement",
            str(params.get("opt_placement_fraction", None))
        ])
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            params.get("opt_column_column", None)
        ])
    if params.get("border", None) is not None:
        cargs.extend([a for c in [cifti_label_to_border_border_cargs(s, execution) for s in params.get("border", None)] for a in c])
    return cargs


def cifti_label_to_border_outputs(
    params: CiftiLabelToBorderParameters,
    execution: Execution,
) -> CiftiLabelToBorderOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiLabelToBorderOutputs(
        root=execution.output_file("."),
        border=[cifti_label_to_border_border_outputs(i, execution) if cifti_label_to_border_border_outputs else None for i in params.get("border")] if params.get("border") else None,
    )
    return ret


def cifti_label_to_border_execute(
    params: CiftiLabelToBorderParameters,
    runner: Runner | None = None,
) -> CiftiLabelToBorderOutputs:
    """
    cifti-label-to-border
    
    Draw borders around cifti labels.
    
    For each surface, takes the labels on the matching structure and draws
    borders around the labels. Use -column to only draw borders around one label
    map.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiLabelToBorderOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_LABEL_TO_BORDER_METADATA)
    params = execution.params(params)
    cargs = cifti_label_to_border_cargs(params, execution)
    ret = cifti_label_to_border_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_label_to_border(
    cifti_in: InputPathType,
    opt_placement_fraction: float | None = None,
    opt_column_column: str | None = None,
    border: list[CiftiLabelToBorderBorderParameters] | None = None,
    runner: Runner | None = None,
) -> CiftiLabelToBorderOutputs:
    """
    cifti-label-to-border
    
    Draw borders around cifti labels.
    
    For each surface, takes the labels on the matching structure and draws
    borders around the labels. Use -column to only draw borders around one label
    map.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the input cifti dlabel file.
        opt_placement_fraction: set how far along the edge border points are\
            drawn: fraction along edge from inside vertex (default 0.33).
        opt_column_column: select a single column: the column number or name.
        border: specify output file for a surface structure.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiLabelToBorderOutputs`).
    """
    params = cifti_label_to_border_params(
        cifti_in=cifti_in,
        opt_placement_fraction=opt_placement_fraction,
        opt_column_column=opt_column_column,
        border=border,
    )
    return cifti_label_to_border_execute(params, runner)


__all__ = [
    "CIFTI_LABEL_TO_BORDER_METADATA",
    "CiftiLabelToBorderBorderOutputs",
    "CiftiLabelToBorderOutputs",
    "cifti_label_to_border",
    "cifti_label_to_border_border_params",
    "cifti_label_to_border_execute",
    "cifti_label_to_border_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_INFORMATION_METADATA = Metadata(
    id="237f94d9fda300e4c808bf66e35bc7a6bf87f07a.boutiques",
    name="surface-information",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceInformationParameters = typing.TypedDict('SurfaceInformationParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-information"]],
    "surface_file": InputPathType,
})
SurfaceInformationParametersTagged = typing.TypedDict('SurfaceInformationParametersTagged', {
    "@type": typing.Literal["workbench/surface-information"],
    "surface_file": InputPathType,
})


class SurfaceInformationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceInformationParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def surface_information_params(
    surface_file: InputPathType,
) -> SurfaceInformationParametersTagged:
    """
    Build parameters.
    
    Args:
        surface_file: Surface for which information is displayed.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-information",
        "surface_file": surface_file,
    }
    return params


def surface_information_cargs(
    params: SurfaceInformationParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-information")
    cargs.append(execution.input_file(params.get("surface_file", None)))
    return cargs


def surface_information_outputs(
    params: SurfaceInformationParameters,
    execution: Execution,
) -> SurfaceInformationOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceInformationOutputs(
        root=execution.output_file("."),
    )
    return ret


def surface_information_execute(
    params: SurfaceInformationParameters,
    runner: Runner | None = None,
) -> SurfaceInformationOutputs:
    """
    surface-information
    
    Display information about a surface.
    
    Information about surface is displayed including vertices,
    triangles, bounding box, and spacing.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceInformationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_INFORMATION_METADATA)
    params = execution.params(params)
    cargs = surface_information_cargs(params, execution)
    ret = surface_information_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_information(
    surface_file: InputPathType,
    runner: Runner | None = None,
) -> SurfaceInformationOutputs:
    """
    surface-information
    
    Display information about a surface.
    
    Information about surface is displayed including vertices,
    triangles, bounding box, and spacing.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface_file: Surface for which information is displayed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceInformationOutputs`).
    """
    params = surface_information_params(
        surface_file=surface_file,
    )
    return surface_information_execute(params, runner)


__all__ = [
    "SURFACE_INFORMATION_METADATA",
    "SurfaceInformationOutputs",
    "surface_information",
    "surface_information_execute",
    "surface_information_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_CHANGE_MAPPING_METADATA = Metadata(
    id="ab237d77e9bc26eb5d7275bd370215569ec47142.boutiques",
    name="cifti-change-mapping",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiChangeMappingSeriesParameters = typing.TypedDict('CiftiChangeMappingSeriesParameters', {
    "@type": typing.NotRequired[typing.Literal["series"]],
    "step": float,
    "start": float,
    "opt_unit_unit": typing.NotRequired[str | None],
})
CiftiChangeMappingSeriesParametersTagged = typing.TypedDict('CiftiChangeMappingSeriesParametersTagged', {
    "@type": typing.Literal["series"],
    "step": float,
    "start": float,
    "opt_unit_unit": typing.NotRequired[str | None],
})


CiftiChangeMappingScalarParameters = typing.TypedDict('CiftiChangeMappingScalarParameters', {
    "@type": typing.NotRequired[typing.Literal["scalar"]],
    "opt_name_file_file": typing.NotRequired[str | None],
})
CiftiChangeMappingScalarParametersTagged = typing.TypedDict('CiftiChangeMappingScalarParametersTagged', {
    "@type": typing.Literal["scalar"],
    "opt_name_file_file": typing.NotRequired[str | None],
})


CiftiChangeMappingFromCiftiParameters = typing.TypedDict('CiftiChangeMappingFromCiftiParameters', {
    "@type": typing.NotRequired[typing.Literal["from_cifti"]],
    "template_cifti": InputPathType,
    "direction": str,
})
CiftiChangeMappingFromCiftiParametersTagged = typing.TypedDict('CiftiChangeMappingFromCiftiParametersTagged', {
    "@type": typing.Literal["from_cifti"],
    "template_cifti": InputPathType,
    "direction": str,
})


CiftiChangeMappingParameters = typing.TypedDict('CiftiChangeMappingParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-change-mapping"]],
    "data_cifti": InputPathType,
    "direction": str,
    "cifti_out": str,
    "series": typing.NotRequired[CiftiChangeMappingSeriesParameters | None],
    "scalar": typing.NotRequired[CiftiChangeMappingScalarParameters | None],
    "from_cifti": typing.NotRequired[CiftiChangeMappingFromCiftiParameters | None],
})
CiftiChangeMappingParametersTagged = typing.TypedDict('CiftiChangeMappingParametersTagged', {
    "@type": typing.Literal["workbench/cifti-change-mapping"],
    "data_cifti": InputPathType,
    "direction": str,
    "cifti_out": str,
    "series": typing.NotRequired[CiftiChangeMappingSeriesParameters | None],
    "scalar": typing.NotRequired[CiftiChangeMappingScalarParameters | None],
    "from_cifti": typing.NotRequired[CiftiChangeMappingFromCiftiParameters | None],
})


def cifti_change_mapping_series_params(
    step: float,
    start: float,
    opt_unit_unit: str | None = None,
) -> CiftiChangeMappingSeriesParametersTagged:
    """
    Build parameters.
    
    Args:
        step: increment between series points.
        start: start value of the series.
        opt_unit_unit: select unit for series (default SECOND): unit identifier.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "series",
        "step": step,
        "start": start,
    }
    if opt_unit_unit is not None:
        params["opt_unit_unit"] = opt_unit_unit
    return params


def cifti_change_mapping_series_cargs(
    params: CiftiChangeMappingSeriesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-series")
    cargs.append(str(params.get("step", None)))
    cargs.append(str(params.get("start", None)))
    if params.get("opt_unit_unit", None) is not None:
        cargs.extend([
            "-unit",
            params.get("opt_unit_unit", None)
        ])
    return cargs


def cifti_change_mapping_scalar_params(
    opt_name_file_file: str | None = None,
) -> CiftiChangeMappingScalarParametersTagged:
    """
    Build parameters.
    
    Args:
        opt_name_file_file: specify names for the maps: text file containing\
            map names, one per line.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "scalar",
    }
    if opt_name_file_file is not None:
        params["opt_name_file_file"] = opt_name_file_file
    return params


def cifti_change_mapping_scalar_cargs(
    params: CiftiChangeMappingScalarParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-scalar")
    if params.get("opt_name_file_file", None) is not None:
        cargs.extend([
            "-name-file",
            params.get("opt_name_file_file", None)
        ])
    return cargs


def cifti_change_mapping_from_cifti_params(
    template_cifti: InputPathType,
    direction: str,
) -> CiftiChangeMappingFromCiftiParametersTagged:
    """
    Build parameters.
    
    Args:
        template_cifti: a cifti file containing the desired mapping.
        direction: which direction to copy the mapping from.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "from_cifti",
        "template_cifti": template_cifti,
        "direction": direction,
    }
    return params


def cifti_change_mapping_from_cifti_cargs(
    params: CiftiChangeMappingFromCiftiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-from-cifti")
    cargs.append(execution.input_file(params.get("template_cifti", None)))
    cargs.append(params.get("direction", None))
    return cargs


class CiftiChangeMappingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiChangeMappingParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_change_mapping_params(
    data_cifti: InputPathType,
    direction: str,
    cifti_out: str,
    series: CiftiChangeMappingSeriesParameters | None = None,
    scalar: CiftiChangeMappingScalarParameters | None = None,
    from_cifti: CiftiChangeMappingFromCiftiParameters | None = None,
) -> CiftiChangeMappingParametersTagged:
    """
    Build parameters.
    
    Args:
        data_cifti: the cifti file to use the data from.
        direction: which direction on <data-cifti> to replace the mapping.
        cifti_out: the output cifti file.
        series: set the mapping to series.
        scalar: set the mapping to scalar.
        from_cifti: copy mapping from another cifti file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-change-mapping",
        "data_cifti": data_cifti,
        "direction": direction,
        "cifti_out": cifti_out,
    }
    if series is not None:
        params["series"] = series
    if scalar is not None:
        params["scalar"] = scalar
    if from_cifti is not None:
        params["from_cifti"] = from_cifti
    return params


def cifti_change_mapping_cargs(
    params: CiftiChangeMappingParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-change-mapping")
    cargs.append(execution.input_file(params.get("data_cifti", None)))
    cargs.append(params.get("direction", None))
    cargs.append(params.get("cifti_out", None))
    if params.get("series", None) is not None:
        cargs.extend(cifti_change_mapping_series_cargs(params.get("series", None), execution))
    if params.get("scalar", None) is not None:
        cargs.extend(cifti_change_mapping_scalar_cargs(params.get("scalar", None), execution))
    if params.get("from_cifti", None) is not None:
        cargs.extend(cifti_change_mapping_from_cifti_cargs(params.get("from_cifti", None), execution))
    return cargs


def cifti_change_mapping_outputs(
    params: CiftiChangeMappingParameters,
    execution: Execution,
) -> CiftiChangeMappingOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiChangeMappingOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_change_mapping_execute(
    params: CiftiChangeMappingParameters,
    runner: Runner | None = None,
) -> CiftiChangeMappingOutputs:
    """
    cifti-change-mapping
    
    Convert to scalar, copy mapping, etc.
    
    Take an existing cifti file and change one of the mappings. Exactly one of
    -series, -scalar, or -from-cifti must be specified. The direction can be
    either an integer starting from 1, or the strings 'ROW' or 'COLUMN'.
    
    The argument to -unit must be one of the following:
    
    SECOND
    HERTZ
    METER
    RADIAN.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiChangeMappingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_CHANGE_MAPPING_METADATA)
    params = execution.params(params)
    cargs = cifti_change_mapping_cargs(params, execution)
    ret = cifti_change_mapping_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_change_mapping(
    data_cifti: InputPathType,
    direction: str,
    cifti_out: str,
    series: CiftiChangeMappingSeriesParameters | None = None,
    scalar: CiftiChangeMappingScalarParameters | None = None,
    from_cifti: CiftiChangeMappingFromCiftiParameters | None = None,
    runner: Runner | None = None,
) -> CiftiChangeMappingOutputs:
    """
    cifti-change-mapping
    
    Convert to scalar, copy mapping, etc.
    
    Take an existing cifti file and change one of the mappings. Exactly one of
    -series, -scalar, or -from-cifti must be specified. The direction can be
    either an integer starting from 1, or the strings 'ROW' or 'COLUMN'.
    
    The argument to -unit must be one of the following:
    
    SECOND
    HERTZ
    METER
    RADIAN.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        data_cifti: the cifti file to use the data from.
        direction: which direction on <data-cifti> to replace the mapping.
        cifti_out: the output cifti file.
        series: set the mapping to series.
        scalar: set the mapping to scalar.
        from_cifti: copy mapping from another cifti file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiChangeMappingOutputs`).
    """
    params = cifti_change_mapping_params(
        data_cifti=data_cifti,
        direction=direction,
        cifti_out=cifti_out,
        series=series,
        scalar=scalar,
        from_cifti=from_cifti,
    )
    return cifti_change_mapping_execute(params, runner)


__all__ = [
    "CIFTI_CHANGE_MAPPING_METADATA",
    "CiftiChangeMappingOutputs",
    "cifti_change_mapping",
    "cifti_change_mapping_execute",
    "cifti_change_mapping_from_cifti_params",
    "cifti_change_mapping_params",
    "cifti_change_mapping_scalar_params",
    "cifti_change_mapping_series_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METRIC_RESAMPLE_METADATA = Metadata(
    id="4d1e7adf2fc4fb2797a0f461eb652d3ebf3b8ce7.boutiques",
    name="metric-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetricResampleAreaSurfsParameters = typing.TypedDict('MetricResampleAreaSurfsParameters', {
    "@type": typing.NotRequired[typing.Literal["area_surfs"]],
    "current_area": InputPathType,
    "new_area": InputPathType,
})
MetricResampleAreaSurfsParametersTagged = typing.TypedDict('MetricResampleAreaSurfsParametersTagged', {
    "@type": typing.Literal["area_surfs"],
    "current_area": InputPathType,
    "new_area": InputPathType,
})


MetricResampleAreaMetricsParameters = typing.TypedDict('MetricResampleAreaMetricsParameters', {
    "@type": typing.NotRequired[typing.Literal["area_metrics"]],
    "current_area": InputPathType,
    "new_area": InputPathType,
})
MetricResampleAreaMetricsParametersTagged = typing.TypedDict('MetricResampleAreaMetricsParametersTagged', {
    "@type": typing.Literal["area_metrics"],
    "current_area": InputPathType,
    "new_area": InputPathType,
})


MetricResampleParameters = typing.TypedDict('MetricResampleParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metric-resample"]],
    "metric_in": InputPathType,
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "method": str,
    "metric_out": str,
    "area_surfs": typing.NotRequired[MetricResampleAreaSurfsParameters | None],
    "area_metrics": typing.NotRequired[MetricResampleAreaMetricsParameters | None],
    "opt_current_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_valid_roi_out_roi_out": typing.NotRequired[str | None],
    "opt_largest": bool,
    "opt_bypass_sphere_check": bool,
})
MetricResampleParametersTagged = typing.TypedDict('MetricResampleParametersTagged', {
    "@type": typing.Literal["workbench/metric-resample"],
    "metric_in": InputPathType,
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "method": str,
    "metric_out": str,
    "area_surfs": typing.NotRequired[MetricResampleAreaSurfsParameters | None],
    "area_metrics": typing.NotRequired[MetricResampleAreaMetricsParameters | None],
    "opt_current_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_valid_roi_out_roi_out": typing.NotRequired[str | None],
    "opt_largest": bool,
    "opt_bypass_sphere_check": bool,
})


def metric_resample_area_surfs_params(
    current_area: InputPathType,
    new_area: InputPathType,
) -> MetricResampleAreaSurfsParametersTagged:
    """
    Build parameters.
    
    Args:
        current_area: a relevant anatomical surface with <current-sphere> mesh.
        new_area: a relevant anatomical surface with <new-sphere> mesh.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "area_surfs",
        "current_area": current_area,
        "new_area": new_area,
    }
    return params


def metric_resample_area_surfs_cargs(
    params: MetricResampleAreaSurfsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-area-surfs")
    cargs.append(execution.input_file(params.get("current_area", None)))
    cargs.append(execution.input_file(params.get("new_area", None)))
    return cargs


def metric_resample_area_metrics_params(
    current_area: InputPathType,
    new_area: InputPathType,
) -> MetricResampleAreaMetricsParametersTagged:
    """
    Build parameters.
    
    Args:
        current_area: a metric file with vertex areas for <current-sphere> mesh.
        new_area: a metric file with vertex areas for <new-sphere> mesh.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "area_metrics",
        "current_area": current_area,
        "new_area": new_area,
    }
    return params


def metric_resample_area_metrics_cargs(
    params: MetricResampleAreaMetricsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-area-metrics")
    cargs.append(execution.input_file(params.get("current_area", None)))
    cargs.append(execution.input_file(params.get("new_area", None)))
    return cargs


class MetricResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricResampleParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""
    opt_valid_roi_out_roi_out: OutputPathType | None
    """output the ROI of vertices that got data from valid source vertices: the
    output roi as a metric"""


def metric_resample_params(
    metric_in: InputPathType,
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    method: str,
    metric_out: str,
    area_surfs: MetricResampleAreaSurfsParameters | None = None,
    area_metrics: MetricResampleAreaMetricsParameters | None = None,
    opt_current_roi_roi_metric: InputPathType | None = None,
    opt_valid_roi_out_roi_out: str | None = None,
    opt_largest: bool = False,
    opt_bypass_sphere_check: bool = False,
) -> MetricResampleParametersTagged:
    """
    Build parameters.
    
    Args:
        metric_in: the metric file to resample.
        current_sphere: a sphere surface with the mesh that the metric is\
            currently on.
        new_sphere: a sphere surface that is in register with <current-sphere>\
            and has the desired output mesh.
        method: the method name.
        metric_out: the output metric.
        area_surfs: specify surfaces to do vertex area correction based on.
        area_metrics: specify vertex area metrics to do area correction based\
            on.
        opt_current_roi_roi_metric: use an input roi on the current mesh to\
            exclude non-data vertices: the roi, as a metric file.
        opt_valid_roi_out_roi_out: output the ROI of vertices that got data\
            from valid source vertices: the output roi as a metric.
        opt_largest: use only the value of the vertex with the largest weight.
        opt_bypass_sphere_check: ADVANCED: allow the current and new 'spheres'\
            to have arbitrary shape as long as they follow the same contour.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metric-resample",
        "metric_in": metric_in,
        "current_sphere": current_sphere,
        "new_sphere": new_sphere,
        "method": method,
        "metric_out": metric_out,
        "opt_largest": opt_largest,
        "opt_bypass_sphere_check": opt_bypass_sphere_check,
    }
    if area_surfs is not None:
        params["area_surfs"] = area_surfs
    if area_metrics is not None:
        params["area_metrics"] = area_metrics
    if opt_current_roi_roi_metric is not None:
        params["opt_current_roi_roi_metric"] = opt_current_roi_roi_metric
    if opt_valid_roi_out_roi_out is not None:
        params["opt_valid_roi_out_roi_out"] = opt_valid_roi_out_roi_out
    return params


def metric_resample_cargs(
    params: MetricResampleParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-resample")
    cargs.append(execution.input_file(params.get("metric_in", None)))
    cargs.append(execution.input_file(params.get("current_sphere", None)))
    cargs.append(execution.input_file(params.get("new_sphere", None)))
    cargs.append(params.get("method", None))
    cargs.append(params.get("metric_out", None))
    if params.get("area_surfs", None) is not None:
        cargs.extend(metric_resample_area_surfs_cargs(params.get("area_surfs", None), execution))
    if params.get("area_metrics", None) is not None:
        cargs.extend(metric_resample_area_metrics_cargs(params.get("area_metrics", None), execution))
    if params.get("opt_current_roi_roi_metric", None) is not None:
        cargs.extend([
            "-current-roi",
            execution.input_file(params.get("opt_current_roi_roi_metric", None))
        ])
    if params.get("opt_valid_roi_out_roi_out", None) is not None:
        cargs.extend([
            "-valid-roi-out",
            params.get("opt_valid_roi_out_roi_out", None)
        ])
    if params.get("opt_largest", False):
        cargs.append("-largest")
    if params.get("opt_bypass_sphere_check", False):
        cargs.append("-bypass-sphere-check")
    return cargs


def metric_resample_outputs(
    params: MetricResampleParameters,
    execution: Execution,
) -> MetricResampleOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricResampleOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
        opt_valid_roi_out_roi_out=execution.output_file(params.get("opt_valid_roi_out_roi_out", None)) if (params.get("opt_valid_roi_out_roi_out") is not None) else None,
    )
    return ret


def metric_resample_execute(
    params: MetricResampleParameters,
    runner: Runner | None = None,
) -> MetricResampleOutputs:
    """
    metric-resample
    
    Resample a metric file to a different mesh.
    
    Resamples a metric file, given two spherical surfaces that are in register.
    If ADAP_BARY_AREA is used, exactly one of -area-surfs or -area-metrics must
    be specified.
    
    The ADAP_BARY_AREA method is recommended for ordinary metric data, because
    it should use all data while downsampling, unlike BARYCENTRIC. The
    recommended areas option for most data is individual midthicknesses for
    individual data, and averaged vertex area metrics from individual
    midthicknesses for group average data.
    
    The -current-roi option only masks the input, the output may be slightly
    dilated in comparison, consider using -metric-mask on the output when using
    -current-roi.
    
    The -largest option results in nearest vertex behavior when used with
    BARYCENTRIC. When resampling a binary metric, consider thresholding at 0.5
    after resampling rather than using -largest.
    
    The <method> argument must be one of the following:
    
    ADAP_BARY_AREA
    BARYCENTRIC
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_RESAMPLE_METADATA)
    params = execution.params(params)
    cargs = metric_resample_cargs(params, execution)
    ret = metric_resample_outputs(params, execution)
    execution.run(cargs)
    return ret


def metric_resample(
    metric_in: InputPathType,
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    method: str,
    metric_out: str,
    area_surfs: MetricResampleAreaSurfsParameters | None = None,
    area_metrics: MetricResampleAreaMetricsParameters | None = None,
    opt_current_roi_roi_metric: InputPathType | None = None,
    opt_valid_roi_out_roi_out: str | None = None,
    opt_largest: bool = False,
    opt_bypass_sphere_check: bool = False,
    runner: Runner | None = None,
) -> MetricResampleOutputs:
    """
    metric-resample
    
    Resample a metric file to a different mesh.
    
    Resamples a metric file, given two spherical surfaces that are in register.
    If ADAP_BARY_AREA is used, exactly one of -area-surfs or -area-metrics must
    be specified.
    
    The ADAP_BARY_AREA method is recommended for ordinary metric data, because
    it should use all data while downsampling, unlike BARYCENTRIC. The
    recommended areas option for most data is individual midthicknesses for
    individual data, and averaged vertex area metrics from individual
    midthicknesses for group average data.
    
    The -current-roi option only masks the input, the output may be slightly
    dilated in comparison, consider using -metric-mask on the output when using
    -current-roi.
    
    The -largest option results in nearest vertex behavior when used with
    BARYCENTRIC. When resampling a binary metric, consider thresholding at 0.5
    after resampling rather than using -largest.
    
    The <method> argument must be one of the following:
    
    ADAP_BARY_AREA
    BARYCENTRIC
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        metric_in: the metric file to resample.
        current_sphere: a sphere surface with the mesh that the metric is\
            currently on.
        new_sphere: a sphere surface that is in register with <current-sphere>\
            and has the desired output mesh.
        method: the method name.
        metric_out: the output metric.
        area_surfs: specify surfaces to do vertex area correction based on.
        area_metrics: specify vertex area metrics to do area correction based\
            on.
        opt_current_roi_roi_metric: use an input roi on the current mesh to\
            exclude non-data vertices: the roi, as a metric file.
        opt_valid_roi_out_roi_out: output the ROI of vertices that got data\
            from valid source vertices: the output roi as a metric.
        opt_largest: use only the value of the vertex with the largest weight.
        opt_bypass_sphere_check: ADVANCED: allow the current and new 'spheres'\
            to have arbitrary shape as long as they follow the same contour.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricResampleOutputs`).
    """
    params = metric_resample_params(
        metric_in=metric_in,
        current_sphere=current_sphere,
        new_sphere=new_sphere,
        method=method,
        metric_out=metric_out,
        area_surfs=area_surfs,
        area_metrics=area_metrics,
        opt_current_roi_roi_metric=opt_current_roi_roi_metric,
        opt_valid_roi_out_roi_out=opt_valid_roi_out_roi_out,
        opt_largest=opt_largest,
        opt_bypass_sphere_check=opt_bypass_sphere_check,
    )
    return metric_resample_execute(params, runner)


__all__ = [
    "METRIC_RESAMPLE_METADATA",
    "MetricResampleOutputs",
    "metric_resample",
    "metric_resample_area_metrics_params",
    "metric_resample_area_surfs_params",
    "metric_resample_execute",
    "metric_resample_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_LABEL_PROBABILITY_METADATA = Metadata(
    id="f07d6d6741808c71835239e6130a80db4872e584.boutiques",
    name="cifti-label-probability",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiLabelProbabilityParameters = typing.TypedDict('CiftiLabelProbabilityParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-label-probability"]],
    "label_maps": InputPathType,
    "probability_dscalar_out": str,
    "opt_exclude_unlabeled": bool,
})
CiftiLabelProbabilityParametersTagged = typing.TypedDict('CiftiLabelProbabilityParametersTagged', {
    "@type": typing.Literal["workbench/cifti-label-probability"],
    "label_maps": InputPathType,
    "probability_dscalar_out": str,
    "opt_exclude_unlabeled": bool,
})


class CiftiLabelProbabilityOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiLabelProbabilityParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    probability_dscalar_out: OutputPathType
    """the relative frequencies of each label at each vertex/voxel"""


def cifti_label_probability_params(
    label_maps: InputPathType,
    probability_dscalar_out: str,
    opt_exclude_unlabeled: bool = False,
) -> CiftiLabelProbabilityParametersTagged:
    """
    Build parameters.
    
    Args:
        label_maps: cifti dlabel file containing individual label maps from\
            many subjects.
        probability_dscalar_out: the relative frequencies of each label at each\
            vertex/voxel.
        opt_exclude_unlabeled: don't make a probability map of the unlabeled\
            key.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-label-probability",
        "label_maps": label_maps,
        "probability_dscalar_out": probability_dscalar_out,
        "opt_exclude_unlabeled": opt_exclude_unlabeled,
    }
    return params


def cifti_label_probability_cargs(
    params: CiftiLabelProbabilityParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-label-probability")
    cargs.append(execution.input_file(params.get("label_maps", None)))
    cargs.append(params.get("probability_dscalar_out", None))
    if params.get("opt_exclude_unlabeled", False):
        cargs.append("-exclude-unlabeled")
    return cargs


def cifti_label_probability_outputs(
    params: CiftiLabelProbabilityParameters,
    execution: Execution,
) -> CiftiLabelProbabilityOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiLabelProbabilityOutputs(
        root=execution.output_file("."),
        probability_dscalar_out=execution.output_file(params.get("probability_dscalar_out", None)),
    )
    return ret


def cifti_label_probability_execute(
    params: CiftiLabelProbabilityParameters,
    runner: Runner | None = None,
) -> CiftiLabelProbabilityOutputs:
    """
    cifti-label-probability
    
    Find frequency of cifti labels.
    
    This command outputs a set of soft ROIs, one for each label in the input,
    where the value is how many of the input maps had that label at that
    vertex/voxel, divided by the number of input maps.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiLabelProbabilityOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_LABEL_PROBABILITY_METADATA)
    params = execution.params(params)
    cargs = cifti_label_probability_cargs(params, execution)
    ret = cifti_label_probability_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_label_probability(
    label_maps: InputPathType,
    probability_dscalar_out: str,
    opt_exclude_unlabeled: bool = False,
    runner: Runner | None = None,
) -> CiftiLabelProbabilityOutputs:
    """
    cifti-label-probability
    
    Find frequency of cifti labels.
    
    This command outputs a set of soft ROIs, one for each label in the input,
    where the value is how many of the input maps had that label at that
    vertex/voxel, divided by the number of input maps.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_maps: cifti dlabel file containing individual label maps from\
            many subjects.
        probability_dscalar_out: the relative frequencies of each label at each\
            vertex/voxel.
        opt_exclude_unlabeled: don't make a probability map of the unlabeled\
            key.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiLabelProbabilityOutputs`).
    """
    params = cifti_label_probability_params(
        label_maps=label_maps,
        probability_dscalar_out=probability_dscalar_out,
        opt_exclude_unlabeled=opt_exclude_unlabeled,
    )
    return cifti_label_probability_execute(params, runner)


__all__ = [
    "CIFTI_LABEL_PROBABILITY_METADATA",
    "CiftiLabelProbabilityOutputs",
    "cifti_label_probability",
    "cifti_label_probability_execute",
    "cifti_label_probability_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_PALETTE_METADATA = Metadata(
    id="d1a247d60a7d3077cf9aec03f5d9b84b67f37b5f.boutiques",
    name="cifti-palette",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiPalettePosPercentParameters = typing.TypedDict('CiftiPalettePosPercentParameters', {
    "@type": typing.NotRequired[typing.Literal["pos_percent"]],
    "pos_min__": float,
    "pos_max__": float,
})
CiftiPalettePosPercentParametersTagged = typing.TypedDict('CiftiPalettePosPercentParametersTagged', {
    "@type": typing.Literal["pos_percent"],
    "pos_min__": float,
    "pos_max__": float,
})


CiftiPaletteNegPercentParameters = typing.TypedDict('CiftiPaletteNegPercentParameters', {
    "@type": typing.NotRequired[typing.Literal["neg_percent"]],
    "neg_min__": float,
    "neg_max__": float,
})
CiftiPaletteNegPercentParametersTagged = typing.TypedDict('CiftiPaletteNegPercentParametersTagged', {
    "@type": typing.Literal["neg_percent"],
    "neg_min__": float,
    "neg_max__": float,
})


CiftiPalettePosUserParameters = typing.TypedDict('CiftiPalettePosUserParameters', {
    "@type": typing.NotRequired[typing.Literal["pos_user"]],
    "pos_min_user": float,
    "pos_max_user": float,
})
CiftiPalettePosUserParametersTagged = typing.TypedDict('CiftiPalettePosUserParametersTagged', {
    "@type": typing.Literal["pos_user"],
    "pos_min_user": float,
    "pos_max_user": float,
})


CiftiPaletteNegUserParameters = typing.TypedDict('CiftiPaletteNegUserParameters', {
    "@type": typing.NotRequired[typing.Literal["neg_user"]],
    "neg_min_user": float,
    "neg_max_user": float,
})
CiftiPaletteNegUserParametersTagged = typing.TypedDict('CiftiPaletteNegUserParametersTagged', {
    "@type": typing.Literal["neg_user"],
    "neg_min_user": float,
    "neg_max_user": float,
})


CiftiPaletteThresholdingParameters = typing.TypedDict('CiftiPaletteThresholdingParameters', {
    "@type": typing.NotRequired[typing.Literal["thresholding"]],
    "type": str,
    "test": str,
    "min": float,
    "max": float,
})
CiftiPaletteThresholdingParametersTagged = typing.TypedDict('CiftiPaletteThresholdingParametersTagged', {
    "@type": typing.Literal["thresholding"],
    "type": str,
    "test": str,
    "min": float,
    "max": float,
})


CiftiPaletteParameters = typing.TypedDict('CiftiPaletteParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-palette"]],
    "cifti_in": InputPathType,
    "mode": str,
    "cifti_out": str,
    "opt_column_column": typing.NotRequired[str | None],
    "pos_percent": typing.NotRequired[CiftiPalettePosPercentParameters | None],
    "neg_percent": typing.NotRequired[CiftiPaletteNegPercentParameters | None],
    "pos_user": typing.NotRequired[CiftiPalettePosUserParameters | None],
    "neg_user": typing.NotRequired[CiftiPaletteNegUserParameters | None],
    "opt_interpolate_interpolate": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_disp_pos_display": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_disp_neg_display": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_disp_zero_display": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_palette_name_name": typing.NotRequired[str | None],
    "thresholding": typing.NotRequired[CiftiPaletteThresholdingParameters | None],
    "opt_inversion_type": typing.NotRequired[str | None],
})
CiftiPaletteParametersTagged = typing.TypedDict('CiftiPaletteParametersTagged', {
    "@type": typing.Literal["workbench/cifti-palette"],
    "cifti_in": InputPathType,
    "mode": str,
    "cifti_out": str,
    "opt_column_column": typing.NotRequired[str | None],
    "pos_percent": typing.NotRequired[CiftiPalettePosPercentParameters | None],
    "neg_percent": typing.NotRequired[CiftiPaletteNegPercentParameters | None],
    "pos_user": typing.NotRequired[CiftiPalettePosUserParameters | None],
    "neg_user": typing.NotRequired[CiftiPaletteNegUserParameters | None],
    "opt_interpolate_interpolate": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_disp_pos_display": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_disp_neg_display": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_disp_zero_display": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_palette_name_name": typing.NotRequired[str | None],
    "thresholding": typing.NotRequired[CiftiPaletteThresholdingParameters | None],
    "opt_inversion_type": typing.NotRequired[str | None],
})


def cifti_palette_pos_percent_params(
    pos_min__: float,
    pos_max__: float,
) -> CiftiPalettePosPercentParametersTagged:
    """
    Build parameters.
    
    Args:
        pos_min__: the percentile for the least positive data.
        pos_max__: the percentile for the most positive data.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "pos_percent",
        "pos_min__": pos_min__,
        "pos_max__": pos_max__,
    }
    return params


def cifti_palette_pos_percent_cargs(
    params: CiftiPalettePosPercentParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-pos-percent")
    cargs.append(str(params.get("pos_min__", None)))
    cargs.append(str(params.get("pos_max__", None)))
    return cargs


def cifti_palette_neg_percent_params(
    neg_min__: float,
    neg_max__: float,
) -> CiftiPaletteNegPercentParametersTagged:
    """
    Build parameters.
    
    Args:
        neg_min__: the percentile for the least negative data.
        neg_max__: the percentile for the most negative data.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "neg_percent",
        "neg_min__": neg_min__,
        "neg_max__": neg_max__,
    }
    return params


def cifti_palette_neg_percent_cargs(
    params: CiftiPaletteNegPercentParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-neg-percent")
    cargs.append(str(params.get("neg_min__", None)))
    cargs.append(str(params.get("neg_max__", None)))
    return cargs


def cifti_palette_pos_user_params(
    pos_min_user: float,
    pos_max_user: float,
) -> CiftiPalettePosUserParametersTagged:
    """
    Build parameters.
    
    Args:
        pos_min_user: the value for the least positive data.
        pos_max_user: the value for the most positive data.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "pos_user",
        "pos_min_user": pos_min_user,
        "pos_max_user": pos_max_user,
    }
    return params


def cifti_palette_pos_user_cargs(
    params: CiftiPalettePosUserParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-pos-user")
    cargs.append(str(params.get("pos_min_user", None)))
    cargs.append(str(params.get("pos_max_user", None)))
    return cargs


def cifti_palette_neg_user_params(
    neg_min_user: float,
    neg_max_user: float,
) -> CiftiPaletteNegUserParametersTagged:
    """
    Build parameters.
    
    Args:
        neg_min_user: the value for the least negative data.
        neg_max_user: the value for the most negative data.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "neg_user",
        "neg_min_user": neg_min_user,
        "neg_max_user": neg_max_user,
    }
    return params


def cifti_palette_neg_user_cargs(
    params: CiftiPaletteNegUserParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-neg-user")
    cargs.append(str(params.get("neg_min_user", None)))
    cargs.append(str(params.get("neg_max_user", None)))
    return cargs


def cifti_palette_thresholding_params(
    type_: str,
    test: str,
    min_: float,
    max_: float,
) -> CiftiPaletteThresholdingParametersTagged:
    """
    Build parameters.
    
    Args:
        type_: thresholding setting.
        test: show values inside or outside thresholds.
        min_: lower threshold.
        max_: upper threshold.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "thresholding",
        "type": type_,
        "test": test,
        "min": min_,
        "max": max_,
    }
    return params


def cifti_palette_thresholding_cargs(
    params: CiftiPaletteThresholdingParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-thresholding")
    cargs.append(params.get("type", None))
    cargs.append(params.get("test", None))
    cargs.append(str(params.get("min", None)))
    cargs.append(str(params.get("max", None)))
    return cargs


class CiftiPaletteOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiPaletteParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_palette_params(
    cifti_in: InputPathType,
    mode: str,
    cifti_out: str,
    opt_column_column: str | None = None,
    pos_percent: CiftiPalettePosPercentParameters | None = None,
    neg_percent: CiftiPaletteNegPercentParameters | None = None,
    pos_user: CiftiPalettePosUserParameters | None = None,
    neg_user: CiftiPaletteNegUserParameters | None = None,
    opt_interpolate_interpolate: typing.Literal["true", "false"] | None = None,
    opt_disp_pos_display: typing.Literal["true", "false"] | None = None,
    opt_disp_neg_display: typing.Literal["true", "false"] | None = None,
    opt_disp_zero_display: typing.Literal["true", "false"] | None = None,
    opt_palette_name_name: str | None = None,
    thresholding: CiftiPaletteThresholdingParameters | None = None,
    opt_inversion_type: str | None = None,
) -> CiftiPaletteParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the cifti input.
        mode: the mapping mode.
        cifti_out: the output cifti file.
        opt_column_column: select a single column for scalar maps: the column\
            number or name.
        pos_percent: percentage min/max for positive data coloring.
        neg_percent: percentage min/max for negative data coloring.
        pos_user: user min/max values for positive data coloring.
        neg_user: user min/max values for negative data coloring.
        opt_interpolate_interpolate: interpolate colors: boolean, whether to\
            interpolate.
        opt_disp_pos_display: display positive data: boolean, whether to\
            display.
        opt_disp_neg_display: display positive data: boolean, whether to\
            display.
        opt_disp_zero_display: display data closer to zero than the min cutoff:\
            boolean, whether to display.
        opt_palette_name_name: set the palette used: the name of the palette.
        thresholding: set the thresholding.
        opt_inversion_type: specify palette inversion: the type of inversion.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-palette",
        "cifti_in": cifti_in,
        "mode": mode,
        "cifti_out": cifti_out,
    }
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    if pos_percent is not None:
        params["pos_percent"] = pos_percent
    if neg_percent is not None:
        params["neg_percent"] = neg_percent
    if pos_user is not None:
        params["pos_user"] = pos_user
    if neg_user is not None:
        params["neg_user"] = neg_user
    if opt_interpolate_interpolate is not None:
        params["opt_interpolate_interpolate"] = opt_interpolate_interpolate
    if opt_disp_pos_display is not None:
        params["opt_disp_pos_display"] = opt_disp_pos_display
    if opt_disp_neg_display is not None:
        params["opt_disp_neg_display"] = opt_disp_neg_display
    if opt_disp_zero_display is not None:
        params["opt_disp_zero_display"] = opt_disp_zero_display
    if opt_palette_name_name is not None:
        params["opt_palette_name_name"] = opt_palette_name_name
    if thresholding is not None:
        params["thresholding"] = thresholding
    if opt_inversion_type is not None:
        params["opt_inversion_type"] = opt_inversion_type
    return params


def cifti_palette_cargs(
    params: CiftiPaletteParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-palette")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    cargs.append(params.get("mode", None))
    cargs.append(params.get("cifti_out", None))
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            params.get("opt_column_column", None)
        ])
    if params.get("pos_percent", None) is not None:
        cargs.extend(cifti_palette_pos_percent_cargs(params.get("pos_percent", None), execution))
    if params.get("neg_percent", None) is not None:
        cargs.extend(cifti_palette_neg_percent_cargs(params.get("neg_percent", None), execution))
    if params.get("pos_user", None) is not None:
        cargs.extend(cifti_palette_pos_user_cargs(params.get("pos_user", None), execution))
    if params.get("neg_user", None) is not None:
        cargs.extend(cifti_palette_neg_user_cargs(params.get("neg_user", None), execution))
    if params.get("opt_interpolate_interpolate", None) is not None:
        cargs.extend([
            "-interpolate",
            params.get("opt_interpolate_interpolate", None)
        ])
    if params.get("opt_disp_pos_display", None) is not None:
        cargs.extend([
            "-disp-pos",
            params.get("opt_disp_pos_display", None)
        ])
    if params.get("opt_disp_neg_display", None) is not None:
        cargs.extend([
            "-disp-neg",
            params.get("opt_disp_neg_display", None)
        ])
    if params.get("opt_disp_zero_display", None) is not None:
        cargs.extend([
            "-disp-zero",
            params.get("opt_disp_zero_display", None)
        ])
    if params.get("opt_palette_name_name", None) is not None:
        cargs.extend([
            "-palette-name",
            params.get("opt_palette_name_name", None)
        ])
    if params.get("thresholding", None) is not None:
        cargs.extend(cifti_palette_thresholding_cargs(params.get("thresholding", None), execution))
    if params.get("opt_inversion_type", None) is not None:
        cargs.extend([
            "-inversion",
            params.get("opt_inversion_type", None)
        ])
    return cargs


def cifti_palette_outputs(
    params: CiftiPaletteParameters,
    execution: Execution,
) -> CiftiPaletteOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiPaletteOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_palette_execute(
    params: CiftiPaletteParameters,
    runner: Runner | None = None,
) -> CiftiPaletteOutputs:
    """
    cifti-palette
    
    Set palette on a cifti file.
    
    NOTE: The output file must be a different file than the input file.
    
    For scalar maps, by default the palette is changed for every map, specify
    -column to change only one map. Palette settings not specified will be taken
    from the first column for scalar maps, and from the existing file palette
    for other mapping types. The <mode> argument must be one of the following:
    
    MODE_AUTO_SCALE
    MODE_AUTO_SCALE_ABSOLUTE_PERCENTAGE
    MODE_AUTO_SCALE_PERCENTAGE
    MODE_USER_SCALE
    
    The <name> argument to -palette-name must be one of the following:
    
    ROY-BIG-BL
    videen_style
    Gray_Interp_Positive
    Gray_Interp
    PSYCH-FIXED
    RBGYR20
    RBGYR20P
    RYGBR4_positive
    RGRBR_mirror90_pos
    Orange-Yellow
    POS_NEG_ZERO
    red-yellow
    blue-lightblue
    FSL
    power_surf
    black-red
    black-green
    black-blue
    black-red-positive
    black-green-positive
    black-blue-positive
    blue-black-green
    blue-black-red
    red-black-green
    fsl_red
    fsl_green
    fsl_blue
    fsl_yellow
    RedWhiteBlue
    cool-warm
    spectral
    RY-BC-BL
    magma
    JET256
    PSYCH
    PSYCH-NO-NONE
    ROY-BIG
    clear_brain
    fidl
    raich4_clrmid
    raich6_clrmid
    HSB8_clrmid
    POS_NEG
    Special-RGB-Volume
    
    The <type> argument to -thresholding must be one of the following:
    
    THRESHOLD_TYPE_OFF
    THRESHOLD_TYPE_NORMAL
    THRESHOLD_TYPE_FILE
    
    The <test> argument to -thresholding must be one of the following:
    
    THRESHOLD_TEST_SHOW_OUTSIDE
    THRESHOLD_TEST_SHOW_INSIDE
    
    The <type> argument to -inversion must be one of the following:
    
    OFF
    POSITIVE_WITH_NEGATIVE
    POSITIVE_NEGATIVE_SEPARATE
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiPaletteOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_PALETTE_METADATA)
    params = execution.params(params)
    cargs = cifti_palette_cargs(params, execution)
    ret = cifti_palette_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_palette(
    cifti_in: InputPathType,
    mode: str,
    cifti_out: str,
    opt_column_column: str | None = None,
    pos_percent: CiftiPalettePosPercentParameters | None = None,
    neg_percent: CiftiPaletteNegPercentParameters | None = None,
    pos_user: CiftiPalettePosUserParameters | None = None,
    neg_user: CiftiPaletteNegUserParameters | None = None,
    opt_interpolate_interpolate: typing.Literal["true", "false"] | None = None,
    opt_disp_pos_display: typing.Literal["true", "false"] | None = None,
    opt_disp_neg_display: typing.Literal["true", "false"] | None = None,
    opt_disp_zero_display: typing.Literal["true", "false"] | None = None,
    opt_palette_name_name: str | None = None,
    thresholding: CiftiPaletteThresholdingParameters | None = None,
    opt_inversion_type: str | None = None,
    runner: Runner | None = None,
) -> CiftiPaletteOutputs:
    """
    cifti-palette
    
    Set palette on a cifti file.
    
    NOTE: The output file must be a different file than the input file.
    
    For scalar maps, by default the palette is changed for every map, specify
    -column to change only one map. Palette settings not specified will be taken
    from the first column for scalar maps, and from the existing file palette
    for other mapping types. The <mode> argument must be one of the following:
    
    MODE_AUTO_SCALE
    MODE_AUTO_SCALE_ABSOLUTE_PERCENTAGE
    MODE_AUTO_SCALE_PERCENTAGE
    MODE_USER_SCALE
    
    The <name> argument to -palette-name must be one of the following:
    
    ROY-BIG-BL
    videen_style
    Gray_Interp_Positive
    Gray_Interp
    PSYCH-FIXED
    RBGYR20
    RBGYR20P
    RYGBR4_positive
    RGRBR_mirror90_pos
    Orange-Yellow
    POS_NEG_ZERO
    red-yellow
    blue-lightblue
    FSL
    power_surf
    black-red
    black-green
    black-blue
    black-red-positive
    black-green-positive
    black-blue-positive
    blue-black-green
    blue-black-red
    red-black-green
    fsl_red
    fsl_green
    fsl_blue
    fsl_yellow
    RedWhiteBlue
    cool-warm
    spectral
    RY-BC-BL
    magma
    JET256
    PSYCH
    PSYCH-NO-NONE
    ROY-BIG
    clear_brain
    fidl
    raich4_clrmid
    raich6_clrmid
    HSB8_clrmid
    POS_NEG
    Special-RGB-Volume
    
    The <type> argument to -thresholding must be one of the following:
    
    THRESHOLD_TYPE_OFF
    THRESHOLD_TYPE_NORMAL
    THRESHOLD_TYPE_FILE
    
    The <test> argument to -thresholding must be one of the following:
    
    THRESHOLD_TEST_SHOW_OUTSIDE
    THRESHOLD_TEST_SHOW_INSIDE
    
    The <type> argument to -inversion must be one of the following:
    
    OFF
    POSITIVE_WITH_NEGATIVE
    POSITIVE_NEGATIVE_SEPARATE
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the cifti input.
        mode: the mapping mode.
        cifti_out: the output cifti file.
        opt_column_column: select a single column for scalar maps: the column\
            number or name.
        pos_percent: percentage min/max for positive data coloring.
        neg_percent: percentage min/max for negative data coloring.
        pos_user: user min/max values for positive data coloring.
        neg_user: user min/max values for negative data coloring.
        opt_interpolate_interpolate: interpolate colors: boolean, whether to\
            interpolate.
        opt_disp_pos_display: display positive data: boolean, whether to\
            display.
        opt_disp_neg_display: display positive data: boolean, whether to\
            display.
        opt_disp_zero_display: display data closer to zero than the min cutoff:\
            boolean, whether to display.
        opt_palette_name_name: set the palette used: the name of the palette.
        thresholding: set the thresholding.
        opt_inversion_type: specify palette inversion: the type of inversion.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiPaletteOutputs`).
    """
    params = cifti_palette_params(
        cifti_in=cifti_in,
        mode=mode,
        cifti_out=cifti_out,
        opt_column_column=opt_column_column,
        pos_percent=pos_percent,
        neg_percent=neg_percent,
        pos_user=pos_user,
        neg_user=neg_user,
        opt_interpolate_interpolate=opt_interpolate_interpolate,
        opt_disp_pos_display=opt_disp_pos_display,
        opt_disp_neg_display=opt_disp_neg_display,
        opt_disp_zero_display=opt_disp_zero_display,
        opt_palette_name_name=opt_palette_name_name,
        thresholding=thresholding,
        opt_inversion_type=opt_inversion_type,
    )
    return cifti_palette_execute(params, runner)


__all__ = [
    "CIFTI_PALETTE_METADATA",
    "CiftiPaletteOutputs",
    "cifti_palette",
    "cifti_palette_execute",
    "cifti_palette_neg_percent_params",
    "cifti_palette_neg_user_params",
    "cifti_palette_params",
    "cifti_palette_pos_percent_params",
    "cifti_palette_pos_user_params",
    "cifti_palette_thresholding_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_RESAMPLE_METADATA = Metadata(
    id="7182598b31901aea230333f6711cb7e4f51b6bd1.boutiques",
    name="volume-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeResampleFlirtParameters = typing.TypedDict('VolumeResampleFlirtParameters', {
    "@type": typing.NotRequired[typing.Literal["flirt"]],
    "source_volume": str,
    "target_volume": str,
})
VolumeResampleFlirtParametersTagged = typing.TypedDict('VolumeResampleFlirtParametersTagged', {
    "@type": typing.Literal["flirt"],
    "source_volume": str,
    "target_volume": str,
})


VolumeResampleAffineParameters = typing.TypedDict('VolumeResampleAffineParameters', {
    "@type": typing.NotRequired[typing.Literal["affine"]],
    "affine": str,
    "flirt": typing.NotRequired[VolumeResampleFlirtParameters | None],
})
VolumeResampleAffineParametersTagged = typing.TypedDict('VolumeResampleAffineParametersTagged', {
    "@type": typing.Literal["affine"],
    "affine": str,
    "flirt": typing.NotRequired[VolumeResampleFlirtParameters | None],
})


VolumeResampleFlirt1Parameters = typing.TypedDict('VolumeResampleFlirt1Parameters', {
    "@type": typing.NotRequired[typing.Literal["flirt_1"]],
    "source_volume": str,
    "target_volume": str,
})
VolumeResampleFlirt1ParametersTagged = typing.TypedDict('VolumeResampleFlirt1ParametersTagged', {
    "@type": typing.Literal["flirt_1"],
    "source_volume": str,
    "target_volume": str,
})


VolumeResampleAffineSeriesParameters = typing.TypedDict('VolumeResampleAffineSeriesParameters', {
    "@type": typing.NotRequired[typing.Literal["affine_series"]],
    "affine_series": str,
    "flirt": typing.NotRequired[VolumeResampleFlirt1Parameters | None],
})
VolumeResampleAffineSeriesParametersTagged = typing.TypedDict('VolumeResampleAffineSeriesParametersTagged', {
    "@type": typing.Literal["affine_series"],
    "affine_series": str,
    "flirt": typing.NotRequired[VolumeResampleFlirt1Parameters | None],
})


VolumeResampleWarpParameters = typing.TypedDict('VolumeResampleWarpParameters', {
    "@type": typing.NotRequired[typing.Literal["warp"]],
    "warpfield": str,
    "opt_fnirt_source_volume": typing.NotRequired[str | None],
})
VolumeResampleWarpParametersTagged = typing.TypedDict('VolumeResampleWarpParametersTagged', {
    "@type": typing.Literal["warp"],
    "warpfield": str,
    "opt_fnirt_source_volume": typing.NotRequired[str | None],
})


VolumeResampleParameters = typing.TypedDict('VolumeResampleParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-resample"]],
    "volume_in": InputPathType,
    "volume_space": str,
    "method": str,
    "volume_out": str,
    "affine": typing.NotRequired[list[VolumeResampleAffineParameters] | None],
    "affine_series": typing.NotRequired[list[VolumeResampleAffineSeriesParameters] | None],
    "warp": typing.NotRequired[list[VolumeResampleWarpParameters] | None],
})
VolumeResampleParametersTagged = typing.TypedDict('VolumeResampleParametersTagged', {
    "@type": typing.Literal["workbench/volume-resample"],
    "volume_in": InputPathType,
    "volume_space": str,
    "method": str,
    "volume_out": str,
    "affine": typing.NotRequired[list[VolumeResampleAffineParameters] | None],
    "affine_series": typing.NotRequired[list[VolumeResampleAffineSeriesParameters] | None],
    "warp": typing.NotRequired[list[VolumeResampleWarpParameters] | None],
})


def volume_resample_flirt_params(
    source_volume: str,
    target_volume: str,
) -> VolumeResampleFlirtParametersTagged:
    """
    Build parameters.
    
    Args:
        source_volume: the source volume used when generating the affine.
        target_volume: the target volume used when generating the affine.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "flirt",
        "source_volume": source_volume,
        "target_volume": target_volume,
    }
    return params


def volume_resample_flirt_cargs(
    params: VolumeResampleFlirtParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-flirt")
    cargs.append(params.get("source_volume", None))
    cargs.append(params.get("target_volume", None))
    return cargs


def volume_resample_affine_params(
    affine: str,
    flirt: VolumeResampleFlirtParameters | None = None,
) -> VolumeResampleAffineParametersTagged:
    """
    Build parameters.
    
    Args:
        affine: the affine file to use.
        flirt: MUST be used if affine is a flirt affine.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "affine",
        "affine": affine,
    }
    if flirt is not None:
        params["flirt"] = flirt
    return params


def volume_resample_affine_cargs(
    params: VolumeResampleAffineParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-affine")
    cargs.append(params.get("affine", None))
    if params.get("flirt", None) is not None:
        cargs.extend(volume_resample_flirt_cargs(params.get("flirt", None), execution))
    return cargs


def volume_resample_flirt_1_params(
    source_volume: str,
    target_volume: str,
) -> VolumeResampleFlirt1ParametersTagged:
    """
    Build parameters.
    
    Args:
        source_volume: the source volume used when generating the affine.
        target_volume: the target volume used when generating the affine.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "flirt_1",
        "source_volume": source_volume,
        "target_volume": target_volume,
    }
    return params


def volume_resample_flirt_1_cargs(
    params: VolumeResampleFlirt1Parameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-flirt")
    cargs.append(params.get("source_volume", None))
    cargs.append(params.get("target_volume", None))
    return cargs


def volume_resample_affine_series_params(
    affine_series: str,
    flirt: VolumeResampleFlirt1Parameters | None = None,
) -> VolumeResampleAffineSeriesParametersTagged:
    """
    Build parameters.
    
    Args:
        affine_series: text file containing 12 or 16 numbers per line, each\
            being a row-major flattened affine.
        flirt: MUST be used if the affines are flirt affines.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "affine_series",
        "affine_series": affine_series,
    }
    if flirt is not None:
        params["flirt"] = flirt
    return params


def volume_resample_affine_series_cargs(
    params: VolumeResampleAffineSeriesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-affine-series")
    cargs.append(params.get("affine_series", None))
    if params.get("flirt", None) is not None:
        cargs.extend(volume_resample_flirt_1_cargs(params.get("flirt", None), execution))
    return cargs


def volume_resample_warp_params(
    warpfield: str,
    opt_fnirt_source_volume: str | None = None,
) -> VolumeResampleWarpParametersTagged:
    """
    Build parameters.
    
    Args:
        warpfield: the warpfield file.
        opt_fnirt_source_volume: MUST be used if using a fnirt warpfield: the\
            source volume used when generating the warpfield.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "warp",
        "warpfield": warpfield,
    }
    if opt_fnirt_source_volume is not None:
        params["opt_fnirt_source_volume"] = opt_fnirt_source_volume
    return params


def volume_resample_warp_cargs(
    params: VolumeResampleWarpParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-warp")
    cargs.append(params.get("warpfield", None))
    if params.get("opt_fnirt_source_volume", None) is not None:
        cargs.extend([
            "-fnirt",
            params.get("opt_fnirt_source_volume", None)
        ])
    return cargs


class VolumeResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeResampleParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_resample_params(
    volume_in: InputPathType,
    volume_space: str,
    method: str,
    volume_out: str,
    affine: list[VolumeResampleAffineParameters] | None = None,
    affine_series: list[VolumeResampleAffineSeriesParameters] | None = None,
    warp: list[VolumeResampleWarpParameters] | None = None,
) -> VolumeResampleParametersTagged:
    """
    Build parameters.
    
    Args:
        volume_in: volume to resample.
        volume_space: a volume file in the volume space you want for the output.
        method: the resampling method.
        volume_out: the output volume.
        affine: add an affine transform.
        affine_series: add an independent affine per-frame.
        warp: add a nonlinear warpfield transform.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-resample",
        "volume_in": volume_in,
        "volume_space": volume_space,
        "method": method,
        "volume_out": volume_out,
    }
    if affine is not None:
        params["affine"] = affine
    if affine_series is not None:
        params["affine_series"] = affine_series
    if warp is not None:
        params["warp"] = warp
    return params


def volume_resample_cargs(
    params: VolumeResampleParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-resample")
    cargs.append(execution.input_file(params.get("volume_in", None)))
    cargs.append(params.get("volume_space", None))
    cargs.append(params.get("method", None))
    cargs.append(params.get("volume_out", None))
    if params.get("affine", None) is not None:
        cargs.extend([a for c in [volume_resample_affine_cargs(s, execution) for s in params.get("affine", None)] for a in c])
    if params.get("affine_series", None) is not None:
        cargs.extend([a for c in [volume_resample_affine_series_cargs(s, execution) for s in params.get("affine_series", None)] for a in c])
    if params.get("warp", None) is not None:
        cargs.extend([a for c in [volume_resample_warp_cargs(s, execution) for s in params.get("warp", None)] for a in c])
    return cargs


def volume_resample_outputs(
    params: VolumeResampleParameters,
    execution: Execution,
) -> VolumeResampleOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeResampleOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_resample_execute(
    params: VolumeResampleParameters,
    runner: Runner | None = None,
) -> VolumeResampleOutputs:
    """
    volume-resample
    
    Transform and resample a volume file.
    
    Resample a volume file with an arbitrary list of transformations. You may
    specify -affine, -warp, and -affine-series multiple times each, and they
    will be used in the order specified. For instance, for rigid motion
    correction followed by nonlinear atlas registration, specify -affine-series
    first, then -warp. The recommended methods are CUBIC (cubic spline) for most
    data, and ENCLOSING_VOXEL for label data. The parameter <method> must be one
    of:
    
    CUBIC
    ENCLOSING_VOXEL
    TRILINEAR.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_RESAMPLE_METADATA)
    params = execution.params(params)
    cargs = volume_resample_cargs(params, execution)
    ret = volume_resample_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_resample(
    volume_in: InputPathType,
    volume_space: str,
    method: str,
    volume_out: str,
    affine: list[VolumeResampleAffineParameters] | None = None,
    affine_series: list[VolumeResampleAffineSeriesParameters] | None = None,
    warp: list[VolumeResampleWarpParameters] | None = None,
    runner: Runner | None = None,
) -> VolumeResampleOutputs:
    """
    volume-resample
    
    Transform and resample a volume file.
    
    Resample a volume file with an arbitrary list of transformations. You may
    specify -affine, -warp, and -affine-series multiple times each, and they
    will be used in the order specified. For instance, for rigid motion
    correction followed by nonlinear atlas registration, specify -affine-series
    first, then -warp. The recommended methods are CUBIC (cubic spline) for most
    data, and ENCLOSING_VOXEL for label data. The parameter <method> must be one
    of:
    
    CUBIC
    ENCLOSING_VOXEL
    TRILINEAR.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: volume to resample.
        volume_space: a volume file in the volume space you want for the output.
        method: the resampling method.
        volume_out: the output volume.
        affine: add an affine transform.
        affine_series: add an independent affine per-frame.
        warp: add a nonlinear warpfield transform.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeResampleOutputs`).
    """
    params = volume_resample_params(
        volume_in=volume_in,
        volume_space=volume_space,
        method=method,
        volume_out=volume_out,
        affine=affine,
        affine_series=affine_series,
        warp=warp,
    )
    return volume_resample_execute(params, runner)


__all__ = [
    "VOLUME_RESAMPLE_METADATA",
    "VolumeResampleOutputs",
    "volume_resample",
    "volume_resample_affine_params",
    "volume_resample_affine_series_params",
    "volume_resample_execute",
    "volume_resample_flirt_1_params",
    "volume_resample_flirt_params",
    "volume_resample_params",
    "volume_resample_warp_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METRIC_WEIGHTED_STATS_METADATA = Metadata(
    id="11de3ba13f4d3787caff87511e99dbf6fceff494.boutiques",
    name="metric-weighted-stats",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetricWeightedStatsRoiParameters = typing.TypedDict('MetricWeightedStatsRoiParameters', {
    "@type": typing.NotRequired[typing.Literal["roi"]],
    "roi_metric": InputPathType,
    "opt_match_maps": bool,
})
MetricWeightedStatsRoiParametersTagged = typing.TypedDict('MetricWeightedStatsRoiParametersTagged', {
    "@type": typing.Literal["roi"],
    "roi_metric": InputPathType,
    "opt_match_maps": bool,
})


MetricWeightedStatsStdevParameters = typing.TypedDict('MetricWeightedStatsStdevParameters', {
    "@type": typing.NotRequired[typing.Literal["stdev"]],
    "opt_sample": bool,
})
MetricWeightedStatsStdevParametersTagged = typing.TypedDict('MetricWeightedStatsStdevParametersTagged', {
    "@type": typing.Literal["stdev"],
    "opt_sample": bool,
})


MetricWeightedStatsParameters = typing.TypedDict('MetricWeightedStatsParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metric-weighted-stats"]],
    "metric_in": InputPathType,
    "opt_area_surface_area_surface": typing.NotRequired[InputPathType | None],
    "opt_weight_metric_weight_metric": typing.NotRequired[InputPathType | None],
    "opt_column_column": typing.NotRequired[str | None],
    "roi": typing.NotRequired[MetricWeightedStatsRoiParameters | None],
    "opt_mean": bool,
    "stdev": typing.NotRequired[MetricWeightedStatsStdevParameters | None],
    "opt_percentile_percent": typing.NotRequired[float | None],
    "opt_sum": bool,
    "opt_show_map_name": bool,
})
MetricWeightedStatsParametersTagged = typing.TypedDict('MetricWeightedStatsParametersTagged', {
    "@type": typing.Literal["workbench/metric-weighted-stats"],
    "metric_in": InputPathType,
    "opt_area_surface_area_surface": typing.NotRequired[InputPathType | None],
    "opt_weight_metric_weight_metric": typing.NotRequired[InputPathType | None],
    "opt_column_column": typing.NotRequired[str | None],
    "roi": typing.NotRequired[MetricWeightedStatsRoiParameters | None],
    "opt_mean": bool,
    "stdev": typing.NotRequired[MetricWeightedStatsStdevParameters | None],
    "opt_percentile_percent": typing.NotRequired[float | None],
    "opt_sum": bool,
    "opt_show_map_name": bool,
})


def metric_weighted_stats_roi_params(
    roi_metric: InputPathType,
    opt_match_maps: bool = False,
) -> MetricWeightedStatsRoiParametersTagged:
    """
    Build parameters.
    
    Args:
        roi_metric: the roi, as a metric file.
        opt_match_maps: each column of input uses the corresponding column from\
            the roi file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "roi",
        "roi_metric": roi_metric,
        "opt_match_maps": opt_match_maps,
    }
    return params


def metric_weighted_stats_roi_cargs(
    params: MetricWeightedStatsRoiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-roi")
    cargs.append(execution.input_file(params.get("roi_metric", None)))
    if params.get("opt_match_maps", False):
        cargs.append("-match-maps")
    return cargs


def metric_weighted_stats_stdev_params(
    opt_sample: bool = False,
) -> MetricWeightedStatsStdevParametersTagged:
    """
    Build parameters.
    
    Args:
        opt_sample: estimate population stdev from the sample.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "stdev",
        "opt_sample": opt_sample,
    }
    return params


def metric_weighted_stats_stdev_cargs(
    params: MetricWeightedStatsStdevParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-stdev")
    if params.get("opt_sample", False):
        cargs.append("-sample")
    return cargs


class MetricWeightedStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricWeightedStatsParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def metric_weighted_stats_params(
    metric_in: InputPathType,
    opt_area_surface_area_surface: InputPathType | None = None,
    opt_weight_metric_weight_metric: InputPathType | None = None,
    opt_column_column: str | None = None,
    roi: MetricWeightedStatsRoiParameters | None = None,
    opt_mean: bool = False,
    stdev: MetricWeightedStatsStdevParameters | None = None,
    opt_percentile_percent: float | None = None,
    opt_sum: bool = False,
    opt_show_map_name: bool = False,
) -> MetricWeightedStatsParametersTagged:
    """
    Build parameters.
    
    Args:
        metric_in: the input metric.
        opt_area_surface_area_surface: use vertex areas as weights: the surface\
            to use for vertex areas.
        opt_weight_metric_weight_metric: use weights from a metric file: metric\
            file containing the weights.
        opt_column_column: only display output for one column: the column\
            number or name.
        roi: only consider data inside an roi.
        opt_mean: compute weighted mean.
        stdev: compute weighted standard deviation.
        opt_percentile_percent: compute weighted percentile: the percentile to\
            find, must be between 0 and 100.
        opt_sum: compute weighted sum.
        opt_show_map_name: print map index and name before each output.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metric-weighted-stats",
        "metric_in": metric_in,
        "opt_mean": opt_mean,
        "opt_sum": opt_sum,
        "opt_show_map_name": opt_show_map_name,
    }
    if opt_area_surface_area_surface is not None:
        params["opt_area_surface_area_surface"] = opt_area_surface_area_surface
    if opt_weight_metric_weight_metric is not None:
        params["opt_weight_metric_weight_metric"] = opt_weight_metric_weight_metric
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    if roi is not None:
        params["roi"] = roi
    if stdev is not None:
        params["stdev"] = stdev
    if opt_percentile_percent is not None:
        params["opt_percentile_percent"] = opt_percentile_percent
    return params


def metric_weighted_stats_cargs(
    params: MetricWeightedStatsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-weighted-stats")
    cargs.append(execution.input_file(params.get("metric_in", None)))
    if params.get("opt_area_surface_area_surface", None) is not None:
        cargs.extend([
            "-area-surface",
            execution.input_file(params.get("opt_area_surface_area_surface", None))
        ])
    if params.get("opt_weight_metric_weight_metric", None) is not None:
        cargs.extend([
            "-weight-metric",
            execution.input_file(params.get("opt_weight_metric_weight_metric", None))
        ])
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            params.get("opt_column_column", None)
        ])
    if params.get("roi", None) is not None:
        cargs.extend(metric_weighted_stats_roi_cargs(params.get("roi", None), execution))
    if params.get("opt_mean", False):
        cargs.append("-mean")
    if params.get("stdev", None) is not None:
        cargs.extend(metric_weighted_stats_stdev_cargs(params.get("stdev", None), execution))
    if params.get("opt_percentile_percent", None) is not None:
        cargs.extend([
            "-percentile",
            str(params.get("opt_percentile_percent", None))
        ])
    if params.get("opt_sum", False):
        cargs.append("-sum")
    if params.get("opt_show_map_name", False):
        cargs.append("-show-map-name")
    return cargs


def metric_weighted_stats_outputs(
    params: MetricWeightedStatsParameters,
    execution: Execution,
) -> MetricWeightedStatsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricWeightedStatsOutputs(
        root=execution.output_file("."),
    )
    return ret


def metric_weighted_stats_execute(
    params: MetricWeightedStatsParameters,
    runner: Runner | None = None,
) -> MetricWeightedStatsOutputs:
    """
    metric-weighted-stats
    
    Weighted spatial statistics on a metric file.
    
    For each column of the input, a line of text is printed, resulting from the
    specified operation. You must specify exactly one of -area-surface or
    -weight-metric. Use -column to only give output for a single column. If the
    -roi option is used without -match-maps, then each line will contain as many
    numbers as there are maps in the ROI file, separated by tab characters.
    Exactly one of -mean, -stdev, -percentile or -sum must be specified.
    
    Using -sum with -area-surface (or -weight-metric with a metric containing
    similar data) is equivalent to integrating with respect to surface area. For
    example, if you want to find the surface area within an roi, do this:
    
    $ wb_command -metric-weighted-stats roi.func.gii -sum -area-surface
    midthickness.surf.gii.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricWeightedStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_WEIGHTED_STATS_METADATA)
    params = execution.params(params)
    cargs = metric_weighted_stats_cargs(params, execution)
    ret = metric_weighted_stats_outputs(params, execution)
    execution.run(cargs)
    return ret


def metric_weighted_stats(
    metric_in: InputPathType,
    opt_area_surface_area_surface: InputPathType | None = None,
    opt_weight_metric_weight_metric: InputPathType | None = None,
    opt_column_column: str | None = None,
    roi: MetricWeightedStatsRoiParameters | None = None,
    opt_mean: bool = False,
    stdev: MetricWeightedStatsStdevParameters | None = None,
    opt_percentile_percent: float | None = None,
    opt_sum: bool = False,
    opt_show_map_name: bool = False,
    runner: Runner | None = None,
) -> MetricWeightedStatsOutputs:
    """
    metric-weighted-stats
    
    Weighted spatial statistics on a metric file.
    
    For each column of the input, a line of text is printed, resulting from the
    specified operation. You must specify exactly one of -area-surface or
    -weight-metric. Use -column to only give output for a single column. If the
    -roi option is used without -match-maps, then each line will contain as many
    numbers as there are maps in the ROI file, separated by tab characters.
    Exactly one of -mean, -stdev, -percentile or -sum must be specified.
    
    Using -sum with -area-surface (or -weight-metric with a metric containing
    similar data) is equivalent to integrating with respect to surface area. For
    example, if you want to find the surface area within an roi, do this:
    
    $ wb_command -metric-weighted-stats roi.func.gii -sum -area-surface
    midthickness.surf.gii.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        metric_in: the input metric.
        opt_area_surface_area_surface: use vertex areas as weights: the surface\
            to use for vertex areas.
        opt_weight_metric_weight_metric: use weights from a metric file: metric\
            file containing the weights.
        opt_column_column: only display output for one column: the column\
            number or name.
        roi: only consider data inside an roi.
        opt_mean: compute weighted mean.
        stdev: compute weighted standard deviation.
        opt_percentile_percent: compute weighted percentile: the percentile to\
            find, must be between 0 and 100.
        opt_sum: compute weighted sum.
        opt_show_map_name: print map index and name before each output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricWeightedStatsOutputs`).
    """
    params = metric_weighted_stats_params(
        metric_in=metric_in,
        opt_area_surface_area_surface=opt_area_surface_area_surface,
        opt_weight_metric_weight_metric=opt_weight_metric_weight_metric,
        opt_column_column=opt_column_column,
        roi=roi,
        opt_mean=opt_mean,
        stdev=stdev,
        opt_percentile_percent=opt_percentile_percent,
        opt_sum=opt_sum,
        opt_show_map_name=opt_show_map_name,
    )
    return metric_weighted_stats_execute(params, runner)


__all__ = [
    "METRIC_WEIGHTED_STATS_METADATA",
    "MetricWeightedStatsOutputs",
    "metric_weighted_stats",
    "metric_weighted_stats_execute",
    "metric_weighted_stats_params",
    "metric_weighted_stats_roi_params",
    "metric_weighted_stats_stdev_params",
]
